@@ -9,7 +9,7 @@
 #include "bookmarks.h"
 #include "moveviewport.h"
 
-static gint bmid = 0;
+
 
 /**
  *  Find the specified bookmark and go to it.
@@ -24,7 +24,7 @@ findbookmark (DenemoGUI * gui, gint bmbar, gint bmstaff)
   g_assert (gui != NULL);
   set_currentmeasurenum (gui, bmbar);
   set_currentstaffnum (gui, bmstaff);
-
+  //FIXME make these return success or failure & inform of deleted bookmark positions
 }
 
 /**
@@ -40,14 +40,54 @@ addbookmark (GtkAction * action, DenemoGUI * gui)
   Bookmark *bm = (Bookmark *) g_malloc0 (sizeof (Bookmark));
   bm->bar = si->currentmeasurenum;
   bm->staff = si->currentstaffnum;
-  bm->id = ++bmid;
+  if(si->bookmarks)
+    bm->id = g_list_length(si->bookmarks);
 
   si->bookmarks = g_list_append (si->bookmarks, bm);
 
-  g_print ("Bar %d, Staff %d, \n", bm->bar, bm->staff);
-
+  //g_print ("Bar %d, Staff %d, \n", bm->bar, bm->staff);
+}
 
 
+void
+deletebookmarks (GtkAction * action, DenemoGUI * gui)
+{
+  GList *g;
+  DenemoScore *si = gui->si;
+  for(g=si->bookmarks;g;g=g->next) {
+    g_free(g->data);
+  }
+  si->bookmarks = NULL;
+}
+void
+nextbookmark (GtkAction * action, DenemoGUI * gui)
+{
+ if(gui->si->bookmarks){
+   GList *g = g_list_nth(gui->si->bookmarks, gui->si->currentbookmark+1);
+   if(g == NULL) {
+     gdk_beep();//wrap around
+     g = gui->si->bookmarks;
+     gui->si->currentbookmark=-1;
+   }
+   Bookmark *bm = g->data;
+   findbookmark (gui, bm->bar, bm->staff);
+   gui->si->currentbookmark++;
+ }
+}
+void
+prevbookmark (GtkAction * action, DenemoGUI * gui)
+{
+ if(gui->si->bookmarks){
+   GList *g = g_list_nth(gui->si->bookmarks, gui->si->currentbookmark-1);
+   if(g == NULL) {
+     gdk_beep();//wrap around
+     g = g_list_last(gui->si->bookmarks);
+     gui->si->currentbookmark=g_list_length(gui->si->bookmarks)+1;
+   }
+   Bookmark *bm = g->data;
+   findbookmark (gui, bm->bar, bm->staff);
+   gui->si->currentbookmark--;
+ }
 }
 
 /**
@@ -58,6 +98,10 @@ void
 gotobookmark (GtkAction * action, DenemoGUI * gui)
 {
   g_assert (gui != NULL);
+  if(gui->si->bookmarks==NULL) {
+    warningdialog("No bookmarks are present in this movement");
+    return;
+  }
   GtkWidget *dialog;
   GtkWidget *combobox;
   GList *strings = NULL, *tmp;
@@ -71,12 +115,12 @@ gotobookmark (GtkAction * action, DenemoGUI * gui)
 
 
   combobox = gtk_combo_new ();
-  g_print ("List length %d\n", g_list_length (gui->si->bookmarks));
+  //g_print ("List length %d\n", g_list_length (gui->si->bookmarks));
+#define FORMAT "%d : Staff %d : Bar %d"
   for (tmp = gui->si->bookmarks; tmp; tmp = tmp->next)
     {
       Bookmark *bm = (Bookmark *) tmp->data;
-      char *tmpstring = (char *) g_malloc0 (20 * sizeof (char));
-      snprintf (tmpstring, 20, "%d : Staff %d : Bar %d",
+      char *tmpstring = g_strdup_printf(FORMAT,//FIXME insane use of sscanf see below
 		bm->id, bm->staff, bm->bar);
 
       strings = g_list_append (strings, tmpstring);
@@ -101,8 +145,8 @@ gotobookmark (GtkAction * action, DenemoGUI * gui)
       gchar *tmp =
 	(gchar *)
 	gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (combobox)->entry));
-      sscanf (tmp, "%d : Staff %d : Bar %d", &bmid, &bms, &bmb);
-      g_print ("bmid %d\n", bmid);
+      sscanf (tmp, FORMAT, &bmid, &bms, &bmb);
+      //g_print ("bmid %d\n", bmid);
       findbookmark (gui, bmb, bms);
 
     }
