@@ -17,6 +17,9 @@
 
 void addbookmark(GtkAction *action,DenemoGUI *gui);
 void gotobookmark(GtkAction *action, DenemoGUI *gui);
+void nextbookmark(GtkAction *action, DenemoGUI *gui);
+void prevbookmark(GtkAction *action, DenemoGUI *gui);
+void deletebookmarks(GtkAction *action, DenemoGUI *gui);
 
 
 #endif
