@@ -34,7 +34,7 @@
 DenemoObject *curmudelaobj = \
        (DenemoObject *) ( (si->currentobject && si->currentobject->data) ? \
        ((((DenemoObject *)si->currentobject->data)->type == TUPCLOSE) ? \
-       si->currentobject->prev->data : si->currentobject->data) : NULL)
+       (si->currentobject->prev?si->currentobject->prev->data:si->currentobject->data) : si->currentobject->data) : NULL)
 
 
 /**
@@ -43,39 +43,39 @@ DenemoObject *curmudelaobj = \
  * is easy to alternate rhythms.
  */
 void nextrhythm(DenemoGUI *gui) {
-  if(!gui->si->rhythms)
+  if(!gui->rhythms)
     return;
-  if(gui->si->currhythm==NULL)
-    gui->si->currhythm = g_list_last(gui->si->rhythms);
+  if(gui->currhythm==NULL)
+    gui->currhythm = g_list_last(gui->rhythms);
 #if 0
-  gtk_widget_set_state(((RhythmPattern *)gui->si->currhythm->data)->button, GTK_STATE_NORMAL);
+  gtk_widget_set_state(((RhythmPattern *)gui->currhythm->data)->button, GTK_STATE_NORMAL);
 #else
 
   {GdkColor thecolor;
     gdk_color_parse ("gray", &thecolor);
-    gtk_widget_modify_bg (gtk_tool_button_get_label_widget(GTK_TOOL_BUTTON(((RhythmPattern *)gui->si->currhythm->data)->button)), GTK_STATE_NORMAL, &thecolor);
+    gtk_widget_modify_bg (gtk_tool_button_get_label_widget(GTK_TOOL_BUTTON(((RhythmPattern *)gui->currhythm->data)->button)), GTK_STATE_NORMAL, &thecolor);
   }
 
 #endif
-  if(gui->si->currhythm->next)
-    gui->si->currhythm = gui->si->currhythm->next;
+  if(gui->currhythm->next)
+    gui->currhythm = gui->currhythm->next;
   else
-    gui->si->currhythm = gui->si->rhythms;
-#define g  (gui->si->rstep)
+    gui->currhythm = gui->rhythms;
+#define g  (gui->rstep)
 
-  g = ((RhythmPattern*)gui->si->currhythm->data)->rsteps;
+  g = ((RhythmPattern*)gui->currhythm->data)->rsteps;
 
 
-#define CURRP ((RhythmPattern *)gui->si->currhythm->data)  
+#define CURRP ((RhythmPattern *)gui->currhythm->data)  
   if(((RhythmElement*)g->data)->icon) {
     GtkWidget *label = LABEL(CURRP->button);
-    g_print("markup is %s\n", ((RhythmElement*)g->data)->icon);
+    //g_print("markup is %s\n", ((RhythmElement*)g->data)->icon);
     gtk_label_set_markup(GTK_LABEL(label),((RhythmElement*)g->data)->icon);
   }
 #if 0
-  gtk_widget_set_state(GTK_WIDGET(((RhythmPattern *)gui->si->currhythm->data)->button), GTK_STATE_PRELIGHT);
+  gtk_widget_set_state(GTK_WIDGET(((RhythmPattern *)gui->currhythm->data)->button), GTK_STATE_PRELIGHT);
 #else
-  highlight_rhythm((RhythmPattern *)gui->si->currhythm->data);
+  highlight_rhythm((RhythmPattern *)gui->currhythm->data);
 #endif
   //g_print("selected active\n");
 #undef CURRP
@@ -142,16 +142,16 @@ setcurrents (DenemoScore * si)
  * displayed portion
  */
 void
-nudgerightward (DenemoGUI * si)
+nudgerightward (DenemoGUI * gui)
 {
-  set_rightmeasurenum (si->si);
-  while (si->si->currentmeasurenum > si->si->rightmeasurenum)
+  set_rightmeasurenum (gui->si);
+  while (gui->si->currentmeasurenum > gui->si->rightmeasurenum)
     {
-      si->si->leftmeasurenum++;
-      set_rightmeasurenum (si->si);
+      gui->si->leftmeasurenum++;
+      set_rightmeasurenum (gui->si);
     }
-  find_leftmost_allcontexts (si->si);
-  update_hscrollbar (si);
+  find_leftmost_allcontexts (gui->si);
+  update_hscrollbar (gui);
 }
 
 /**
@@ -172,12 +172,14 @@ nudge_downward (DenemoGUI * gui)
 }
 
 /**
- * Set the width of the working scorearea
+ * Set the width available for drawing the measures of the movements from the width of the working scorearea widget
  */
 void
 set_width_to_work_with (DenemoGUI * gui)
 {
-  gui->si->widthtoworkwith
+  GList *g; 
+  for(g = gui->movements;g;g=g->next)
+ ((DenemoScore*) g->data)->widthtoworkwith
     = (gui->scorearea->allocation.width
        - (RIGHT_MARGIN + KEY_MARGIN + gui->si->maxkeywidth + SPACE_FOR_TIME));
 }
@@ -302,11 +304,67 @@ measureright (DenemoGUI * gui)
     }
 }
 
+
 /**
- * Move up an entire staff
+ * swap the current movement for the previous one in the list of movements
  *
  */
-void
+gboolean
+swapmovements (GtkAction *action, DenemoGUI * gui)
+{
+  GList *this = g_list_find( gui->movements, gui->si);
+  if(this->prev) {
+    GList * prev = this->prev;
+    GList * prevv = prev->prev;
+    GList * next = this->next;
+    if(next)
+      next->prev = prev;
+    if(prevv)
+      prevv->next = this;
+    else
+      gui->movements = this;
+    this->next = prev;
+    this->prev = prevv;
+    prev->next = next;
+    prev->prev = this;
+    gchar *str = g_strdup_printf("This movement is now number %d in the score", 1+g_list_index(gui->movements, gui->si));
+    warningdialog(str);//FIXME use an informative not a warning
+    g_free(str);
+  } else
+    warningdialog("There is no previous movement to swap with");
+}
+/**
+ * 
+ *
+ */
+gboolean
+swapstaffs (GtkAction *action, DenemoGUI * gui)
+{
+  if (gui->si->currentstaff && gui->si->currentstaff->prev)
+    {
+      gpointer *temp;
+      temp = gui->si->currentstaff->data;
+      gui->si->currentstaff->data = gui->si->currentstaff->prev->data;
+      gui->si->currentstaff->prev->data = temp;
+      gui->si->currentstaffnum--;
+      gui->si->currentstaff = gui->si->currentstaff->prev;
+      setcurrentprimarystaff (gui->si);
+      setcurrents (gui->si);
+      move_viewport_up (gui);
+      score_status(gui, TRUE);
+      return TRUE;
+    }
+  return FALSE;
+}
+
+
+
+
+/**
+ * Move si->currentstaff up an one staff/voice, return TRUE if successful
+ *
+ */
+gboolean
 staffup (DenemoGUI * gui)
 {
   if (gui->si->currentstaff && gui->si->currentstaff->prev)
@@ -316,14 +374,17 @@ staffup (DenemoGUI * gui)
       setcurrentprimarystaff (gui->si);
       setcurrents (gui->si);
       move_viewport_up (gui);
+      return TRUE;
     }
+  return FALSE;
 }
 
+
 /**
- * Move down an entire staff
+ * Move si->currentstaff down an one staff/voice, return TRUE if successful
  *
  */
-void
+gboolean
 staffdown (DenemoGUI * gui)
 {
   if (gui->si->currentstaff->next)
@@ -381,6 +442,7 @@ cursorleft (DenemoGUI * gui)
 	}
     }
   calcmarkboundaries (si);
+  write_status(gui);
 }
 
 /**
@@ -419,6 +481,7 @@ cursorright (DenemoGUI * gui)
 	}
     }
   calcmarkboundaries (si);
+  write_status(gui);
 }
 
 /**
@@ -429,7 +492,7 @@ cursorup (DenemoGUI * gui)
 {
   gui->si->cursor_y++;
   gui->si->staffletter_y = (gui->si->staffletter_y + 1) % 7;
-  g_print ("Cursor Y Position %d\n", gui->si->cursor_y);
+  //g_print ("Cursor Y Position %d\n", gui->si->cursor_y);
 }
 
 /**
@@ -440,7 +503,7 @@ cursordown (DenemoGUI * gui)
 {
   gui->si->cursor_y--;
   gui->si->staffletter_y = (gui->si->staffletter_y + 6) % 7;
-  g_print ("Cursor Y Position %d\n", gui->si->cursor_y);
+  //g_print ("Cursor Y Position %d\n", gui->si->cursor_y);
 }
 
 /**
@@ -459,6 +522,11 @@ shiftcursor (DenemoGUI  *gui, gint note_value)
   gui->si->cursor_y = jumpcursor (gui->si->cursor_y, oldstaffletter_y,
 				  gui->si->staffletter_y);
   int mid_c_offset = gui->si->cursor_y;
+  if((gui->mode & INPUTRHYTHM)&&!(gui->mode&INPUTINSERT)){
+    warningdialog("Rhythm only mode - enter durations, not notes!");
+    return;
+  }
+     
   /* in edit mode edit the current note name */
   if((gui->mode & INPUTEDIT) && gui->si->currentobject) {
     DenemoObject *theobj =  (DenemoObject *)(gui->si->currentobject->data);
@@ -476,10 +544,11 @@ shiftcursor (DenemoGUI  *gui, gint note_value)
       showwhichaccidentals ((objnode *) gui->si->currentmeasure->data,
 			    gui->si->curmeasurekey, gui->si->curmeasureaccs);
       }
+      score_status(gui, TRUE);
     }  
   } else
     /* in INSERT (or EDIT with no currentobject) we insert a note using the next step of the rhythm pattern */
-#define g  (gui->si->rstep)
+#define g  (gui->rstep)
   if((gui->mode&(INPUTEDIT|INPUTINSERT)) && g) {
       GList *start = g;
       GList *h;
@@ -495,12 +564,13 @@ shiftcursor (DenemoGUI  *gui, gint note_value)
 	  g = g->next;/* list is circular */
 	}
       } while(g!=start && modifier_code(h->data));
-#define CURRP ((RhythmPattern *)gui->si->currhythm->data)    
+#define CURRP ((RhythmPattern *)gui->currhythm->data)    
       if(((RhythmElement*)g->data)->icon) {/* singletons do not have icon */
 	GtkWidget *label = LABEL(CURRP->button);
 	//g_print("Markup is %s\n", ((RhythmElement*)g->data)->icon);
 	gtk_label_set_markup(GTK_LABEL(label),((RhythmElement*)g->data)->icon);
       }
+      score_status(gui, TRUE);
     }
 #undef CURRP
 #undef g
@@ -509,7 +579,7 @@ shiftcursor (DenemoGUI  *gui, gint note_value)
 
 void
 insert_rhythm_pattern(DenemoGUI  *gui) {
-#define g  (gui->si->rstep)
+#define g  (gui->rstep)
   if((gui->mode&(INPUTEDIT)) && g) {
     GList *start = g;
     GList *h;
@@ -539,6 +609,7 @@ insert_rhythm_pattern(DenemoGUI  *gui) {
  * that is, if the current measure is full it moves into the next one provided it is empty
  * (or creates a new one and moves into it)
  * if it is not full, or if the next measure is not empty it does nothing.
+ * param ALL add any extra measure to all staffs if the current staff has a full set of measures
 old misleading comment:
  * Goto the next measure 
  * Goto the next measure in the score.  A new measure will
@@ -567,7 +638,8 @@ nextmeasure (DenemoScore * si, gboolean all /*=TRUE */ )
 	  g_debug ("Appending a new measure\n");
 
 	  /* Add a measure and make it currentmeasure */
-	  //    object_insert( si, newbarline( ORDINARY_BARLINE));
+	  if(!(all && si->currentstaff && si->currentstaff && g_list_length(((DenemoStaff *) si->currentstaff->data)->measures) == g_list_length(si->measurewidths)))
+	    all = FALSE; // add only to current staff if it is short
 	  si->currentmeasure =
 	    dnm_addmeasures (si, si->currentmeasurenum, 1, all);
 	}
@@ -603,17 +675,8 @@ dnm_insertchord (DenemoScore * si, gint duration, input_mode mode,
     changeduration(si, duration);
     return;
   }
-
-
-  /* First, check to see if the insertion'll cause the cursor to
-   * jump to the next measure. (Denemo will implicitly create it
-   * if it doesn't exist already.) */
-
   nextmeasure (si, FALSE);
-
-
-
-
+  
   /* Now actually create the chord */
   mudela_obj_new = newchord (duration, 0, 0);
   if ( (mode & INPUTBLANK) && (rest != TRUE))
@@ -681,15 +744,14 @@ dnm_inserttuplet (DenemoScore * si, tuplet_type type)
       mudela_obj_new = newtupopen (2, 3);
       break;
     }
-  g_print ("Cursor pos %d (Before tup open)\n", si->cursor_x);
+  //g_print ("Cursor pos %d (Before tup open)\n", si->cursor_x);
   object_insert (si, mudela_obj_new);
-  g_print ("Cursor pos %d (After tup open, before tup close)\n",
-	   si->cursor_x);
+  //g_print ("Cursor pos %d (After tup open, before tup close)\n",	   si->cursor_x);
   /* Add the closing bracket */
   object_insert (si, newtupclose ());
-  g_print ("Cursor pos %d (After tup close)\n", si->cursor_x);
+  //g_print ("Cursor pos %d (After tup close)\n", si->cursor_x);
   si->cursor_x--;
-  g_print ("Cursor pos %d( After move back)\n", si->cursor_x);
+  //g_print ("Cursor pos %d( After move back)\n", si->cursor_x);
 
   si->currentobject = si->currentobject->prev;
   si->cursor_appending = FALSE;
@@ -786,6 +848,10 @@ displayhelper (DenemoGUI * gui)
 		       si->cursortime2);
   nudgerightward (gui);
   set_bottom_staff(gui);
+  write_status(gui);
+  if ((gui->mode&(INPUTRHYTHM)) && si->currentobject && (((DenemoObject*)(si->currentobject->data))->type==CHORD)&& ((DenemoObject*)(si->currentobject->data))->starttickofnextnote>= WHOLE_NUMTICKS * si->cursortime1/si->cursortime2)
+    gdk_beep(); //Signal new measures in Edit mode to catch out of step entry
+
   /*gtk_widget_draw (gui->scorearea, NULL);*/
   gtk_widget_queue_draw (gui->scorearea);
 }
@@ -809,7 +875,6 @@ incrementenshift (DenemoScore * si, gint direction)
 			    si->curmeasurekey, si->curmeasureaccs);
       find_xes_in_measure (si, si->currentmeasurenum, si->cursortime1,
 			   si->cursortime2);
-      si->haschanged = TRUE;
       if (curmudelaobj->user_string)
 	{
 	  g_free (curmudelaobj->user_string);
@@ -848,7 +913,6 @@ setenshift (DenemoScore * si, gint enshift)
 			    si->curmeasurekey, si->curmeasureaccs);
       find_xes_in_measure (si, si->currentmeasurenum, si->cursortime1,
 			   si->cursortime2);
-      si->haschanged = TRUE;
       if (curmudelaobj->user_string)
 	{
 	  g_free (curmudelaobj->user_string);
@@ -941,7 +1005,6 @@ dnm_insertmeasures (DenemoScore * si, gint number)
   si->cursor_appending = TRUE;
   si->currentobject = NULL;
   set_rightmeasurenum (si);
-  si->haschanged = TRUE;
   si->markstaffnum = 0;
   calcmarkboundaries (si);
   /* update_hscrollbar (si); */
@@ -967,7 +1030,6 @@ appendmeasures (DenemoScore * si, gint number)
     g_list_nth ((objnode *) si->currentmeasure->data,
 		si->cursor_x - (si->cursor_appending == TRUE));
   set_rightmeasurenum (si);
-  si->haschanged = TRUE;
   /*update_hscrollbar (si); */
 }
 
@@ -985,57 +1047,13 @@ appendmeasurestoentirescore (DenemoScore * si, gint number)
     g_list_nth ((objnode *) si->currentmeasure->data,
 		si->cursor_x - (si->cursor_appending == TRUE));
   set_rightmeasurenum (si);
-  si->haschanged = TRUE;
   /* update_hscrollbar (si); */
 
 }
 
-/**
- * Delete staff from the score
- * @param si pointer to the scoreinfo structure
- * @param pos staff number to remove, starts at 1
- * @return none
- */
-static void
-deletestaff (DenemoScore * si, gint pos)
-{
-  if (g_list_length (si->thescore) > 1)
-    {
-      removestaff (si, pos-1, 1);
-      setcurrents (si);
-      find_xes_in_all_measures (si);
-      si->haschanged = TRUE;
-      si->markstaffnum = 0;
-    }
-}
 
 
-/**
- * Delete specific staff defined by callbackaction
- *
- * @param si pointer to the DenemoScore structure
- * @param callback_action position of the staff to delete
- */
-static void
-delete_staff (DenemoScore * si, enum newstaffcallbackaction callback_action)
-{
-  g_print ("Current staff num %d, callback_action %d", si->currentstaffnum,
-	   callback_action);
-  switch (callback_action)
-    {
-    case BEFORE:
-      if (si->currentstaffnum != 1)
-	deletestaff (si, si->currentstaffnum - 1);
-      break;
-    case AFTER:
-      deletestaff (si, si->currentstaffnum + 1);
-      break;
-    default:
-      deletestaff (si, si->currentstaffnum);
-      break;
-    }
-/*  displayhelper(si);*/
-}
+
 
 /**
  * Delete staff wrapper to delete the preceding staff 
@@ -1046,8 +1064,14 @@ delete_staff (DenemoScore * si, enum newstaffcallbackaction callback_action)
 void
 delete_staff_before (GtkAction * action, DenemoGUI * gui)
 {
-  delete_staff (gui->si, BEFORE);
-  displayhelper (gui);
+  DenemoScore *si = gui->si;
+  if (staffup(gui)) {
+    deletestaff (si);
+      setcurrents (si);
+      find_xes_in_all_measures (si);
+      si->markstaffnum = 0;
+    displayhelper (gui);
+  }
 }
 
 /**
@@ -1059,8 +1083,14 @@ delete_staff_before (GtkAction * action, DenemoGUI * gui)
 void
 delete_staff_after (GtkAction * action, DenemoGUI * gui)
 {
-  delete_staff (gui->si, AFTER);
-  displayhelper (gui);
+  DenemoScore *si = gui->si;
+  if (staffdown(gui)) {
+    deletestaff (si);
+      setcurrents (si);
+      find_xes_in_all_measures (si);
+      si->markstaffnum = 0; 
+    displayhelper (gui);
+  }
 }
 
 /**
@@ -1072,7 +1102,11 @@ delete_staff_after (GtkAction * action, DenemoGUI * gui)
 void
 delete_staff_current (GtkAction * action, DenemoGUI * gui)
 {
-  delete_staff (gui->si, CURRENT);
+  DenemoScore *si = gui->si;
+  deletestaff (si);
+      setcurrents (si);
+      find_xes_in_all_measures (si);
+      si->markstaffnum = 0;
   displayhelper (gui);
 }
 
@@ -1092,6 +1126,27 @@ void deletemeasure(DenemoGUI * gui)
 	isoffleftside (gui);
 	displayhelper(gui);
 }
+/**
+ * Delete mesasure from all staffs of score 
+ * @param gui pointer to the DenemoGUI structure
+ * @return none
+ *
+
+ */
+void deletemeasureallstaffs(DenemoGUI * gui)
+{
+  DenemoScore *si=gui->si;
+  si->currentmeasure =
+    removemeasures (si, si->currentmeasurenum - 1, 1, TRUE);
+  setcurrents (si);
+  score_status(gui, TRUE);
+  si->markstaffnum = 0;
+  
+  isoffleftside (gui);
+  displayhelper(gui);
+}
+
+
 
 /**
  * Delete measure from the score
@@ -1111,7 +1166,6 @@ dnm_deletemeasure (DenemoScore * si)
    * the current measure to be the left of what's displayed */
 
   setcurrents (si);
-  si->haschanged = TRUE;
   si->markstaffnum = 0;
 
 
@@ -1185,8 +1239,9 @@ dnm_deleteobject (DenemoScore * si)
   declarecurmudelaobj;
   staffnode *curstaff;
   measurenode *curmeasure;
-  g_print ("dnm_deleteobject undo/redo mode %d\n", si->undo_redo_mode);
-  
+  //g_print ("dnm_deleteobject undo/redo mode %d\n", si->undo_redo_mode);
+  if(curmudelaobj==NULL)
+    return;
   /* when tone_store is active, act on that, not the staff itself */
 
   if (((DenemoStaff*)si->currentstaff->data)->tone_store) {
@@ -1283,8 +1338,6 @@ dnm_deleteobject (DenemoScore * si)
 	case MEASUREBREAK:
 	  break;
 	}
-
-      si->haschanged = TRUE;
       si->markstaffnum = 0;
     }
 }
@@ -1340,34 +1393,6 @@ tohome (GtkAction * action, DenemoGUI * gui)
   gtk_widget_queue_draw (gui->scorearea);
 }
 
-/**
- * Move to the next score block for lilypond mode
- * @param action - Gtk Action event
- * @param gui - pointer to the DenemoGUI structure
- * @return none
-*/
-void
-tonextscore (GtkAction * action, DenemoGUI * gui)
-{
-  GList *g = gui->si->scoreblocks;
-  if (g == NULL)
-    return;
-  /* copy the si to the last in the list si->next,
-     then copy the first to si, and then move the first to the last */
-  memcpy (g_list_last (g)->data, gui->si, sizeof (DenemoScore));
-  memcpy (gui->si, g->data, sizeof (DenemoScore));
-  g = g_list_append (g, g->data);	/* put it on the end */
-#if GTK_MAJOR_VERSION > 1
-
-  g = g_list_delete_link (g, g);	/* and remove it from the beginning */
-#else
-
-  g = g->next;
-#endif
-
-  gui->si->scoreblocks = g;
-  updatescoreinfo (gui->si);
-}
 
 /**
  * Insert stem directive,  absolute stemdirection for the 
@@ -1405,7 +1430,6 @@ toggle_begin_slur (DenemoGUI *gui)
     {
       ((chord *) curmudelaobj->object)->slur_begin_p
 	= !((chord *) curmudelaobj->object)->slur_begin_p;
-      si->haschanged = TRUE;
       if (curmudelaobj->user_string)
 	{
 	  g_free (curmudelaobj->user_string);
@@ -1434,7 +1458,6 @@ caution (DenemoScore * si)
       g_free (curmudelaobj->user_string);
       curmudelaobj->user_string = NULL;
     }
-  si->haschanged = TRUE;
 }
 
 /**
@@ -1452,7 +1475,6 @@ toggle_end_slur (DenemoGUI *gui)
     {
       ((chord *) curmudelaobj->object)->slur_end_p
 	= !((chord *) curmudelaobj->object)->slur_end_p;
-      si->haschanged = TRUE;
       if (curmudelaobj->user_string)
 	{
 	  g_free (curmudelaobj->user_string);
@@ -1477,7 +1499,6 @@ toggle_start_crescendo (DenemoGUI * gui)
     {
       ((chord *) curmudelaobj->object)->crescendo_begin_p
 	= !((chord *) curmudelaobj->object)->crescendo_begin_p;
-      si->haschanged = TRUE;
       if (curmudelaobj->user_string)
 	{
 	  g_free (curmudelaobj->user_string);
@@ -1502,7 +1523,6 @@ toggle_end_crescendo (DenemoGUI *gui)
     {
       ((chord *) curmudelaobj->object)->crescendo_end_p
 	= !((chord *) curmudelaobj->object)->crescendo_end_p;
-      si->haschanged = TRUE;
       if (curmudelaobj->user_string)
 	{
 	  g_free (curmudelaobj->user_string);
@@ -1527,7 +1547,6 @@ toggle_start_diminuendo (DenemoGUI *gui)
     {
       ((chord *) curmudelaobj->object)->diminuendo_begin_p
 	= !((chord *) curmudelaobj->object)->diminuendo_begin_p;
-      si->haschanged = TRUE;
       if (curmudelaobj->user_string)
 	{
 	  g_free (curmudelaobj->user_string);
@@ -1552,7 +1571,6 @@ toggle_end_diminuendo (DenemoGUI *gui)
     {
       ((chord *) curmudelaobj->object)->diminuendo_end_p
 	= !((chord *) curmudelaobj->object)->diminuendo_end_p;
-      si->haschanged = TRUE;
       if (curmudelaobj->user_string)
 	{
 	  g_free (curmudelaobj->user_string);
@@ -1571,29 +1589,34 @@ toggle_end_diminuendo (DenemoGUI *gui)
  * @return none
  */
 gboolean
-auto_save_document_timeout (DenemoScore * si)
+auto_save_document_timeout (DenemoGUI *gui)
 {
-  /*gchar *dir = locatedotdenemo ();*/
+  /* first check that this timer has not been left running after destruction of the gui */
+  if(g_list_find(Denemo.guis, gui)==NULL) {
+    warningdialog("Timer left running");
+    return FALSE; /* turns off the timer */
+  }
+  DenemoScore *si = gui->si;
   g_print ("Autosaving\n");
-  if (!si->autosavename)
+  if (!gui->autosavename)
     {
-      g_warning ("si->autosavename not set\n");
-      /*si->autosavename = g_string_new (dir);*/
-      si->autosavename = g_string_new (locatedotdenemo ());
+      g_warning ("gui->autosavename not set\n");
+      /*gui->autosavename = g_string_new (dir);*/
+      gui->autosavename = g_string_new (locatedotdenemo ());
       if (si->lily_file)
-	si->autosavename = g_string_append (si->autosavename, "/autosave.ly");
+	gui->autosavename = g_string_append (gui->autosavename, "/autosave.ly");
       else
-	si->autosavename =
-	  g_string_append (si->autosavename, "/autosave.denemo");
+	gui->autosavename =
+	  g_string_append (gui->autosavename, "/autosave.denemo");
     }
-  g_print ("Auto save file name %s\n", si->autosavename->str);
+  //g_print ("Auto save file name %s\n", gui->autosavename->str);
   if (si->lily_file)
     {
-      exportlilypond (si->autosavename->str, si, 0, 0);
+      exportlilypond (gui->autosavename->str, gui, 0, 0, 1);
     }
   else
     {
-      exportXML (si->autosavename->str, si, 0, 0);
+      exportXML (gui->autosavename->str, gui, 0, 0);
     }
 
   return TRUE;
