@@ -34,10 +34,16 @@ measureleft (DenemoGUI  *gui);
 void
 measureright (DenemoGUI  *gui);
 
-void
+
+gboolean
+swapstaffs (GtkAction *action, DenemoGUI  *gui);
+gboolean
+swapmovements (GtkAction *action, DenemoGUI  *gui);
+
+gboolean
 staffup (DenemoGUI  *gui);
 
-void
+gboolean
 staffdown (DenemoGUI  *si);
 
 void
@@ -86,8 +92,6 @@ toend (GtkAction *action, DenemoGUI  *gui);
 void
 tohome (GtkAction *action, DenemoGUI  *gui);
 
-void
-tonextscore (GtkAction *action, DenemoGUI  *gui);
 
 void
 inserttuplet (DenemoScore  *si, tuplet_type type);
@@ -125,7 +129,7 @@ caution (DenemoScore  *si);
 
 void displayhelper(DenemoGUI  *si);
 
-gboolean auto_save_document_timeout(DenemoScore  *si);
+gboolean auto_save_document_timeout(DenemoGUI *gui);
 
 
 
@@ -138,6 +142,7 @@ appendmeasurestoentirescore(DenemoScore *si, gint number);
 
 
 void deletemeasure(DenemoGUI * gui);
+void deletemeasureallstaffs(DenemoGUI * gui);
 void deleteobject(DenemoGUI *gui);
 
 void
