@@ -71,10 +71,10 @@ find_leftmost_staffcontext (DenemoStaff * curstaffstruct, DenemoScore * si)
     curstaffstruct->leftmost_keysigcontext = ((keysig *) obj->object)->number;
   else
     curstaffstruct->leftmost_keysigcontext = curstaffstruct->skey;
-  dnm_setinitialkeysig  (curstaffstruct, curstaffstruct->leftmost_keysigcontext,
-      curstaffstruct->skey_isminor);
-  /* initkeyaccs (curstaffstruct->leftmost_keyaccs,
-     curstaffstruct->leftmost_keysigcontext);*/
+  /*  dnm_setinitialkeysig  (curstaffstruct, curstaffstruct->leftmost_keysigcontext,
+      curstaffstruct->skey_isminor);*/
+  initkeyaccs (curstaffstruct->leftmost_keyaccs,
+	       curstaffstruct->leftmost_keysigcontext);
   curstaffstruct->leftmost_keywidth =
     draw_key (NULL, NULL, 0, 0, curstaffstruct->leftmost_keysigcontext,
 	      0, 0, FALSE);
