@@ -82,17 +82,17 @@ csoundplayback (GtkAction * action, DenemoGUI * gui)
 
   filename = g_string_new (get_temp_filename ("denemocsoundplayback.sco"));
   exportcsound (filename->str, gui->si, gui->si->start, gui->si->end);
-  extplayer = gui->prefs->rtcs;
+  extplayer = Denemo.prefs.rtcs;
   if (!extplayer)
     outputfile = g_string_new ("devaudio ");
   else
     outputfile = g_string_new (get_temp_filename ("denemocsoundplayback.wav"));
-  csoundline = g_string_new (gui->prefs->csoundcommand->str);
+  csoundline = g_string_new (Denemo.prefs.csoundcommand->str);
   g_string_append (csoundline, " -o ");
   g_string_append (csoundline, outputfile->str);
   if (extplayer)
     g_string_append (csoundline, " -W ");
-  g_string_append (csoundline, gui->prefs->csoundorcfile->str);
+  g_string_append (csoundline, Denemo.prefs.csoundorcfile->str);
   g_string_append (csoundline, "\t");
   g_string_append (csoundline, filename->str);
   /* the *real* moment: */
@@ -107,7 +107,7 @@ csoundplayback (GtkAction * action, DenemoGUI * gui)
       g_debug ("csound pid %d finished\n", playerpid);
 
       g_string_free (csoundline, TRUE);
-      csoundline = g_string_new (gui->prefs->audioplayer->str);
+      csoundline = g_string_new (Denemo.prefs.audioplayer->str);
       g_string_append (csoundline, "\t");
       g_string_append (csoundline, outputfile->str);
       playerpid = spawn_external (csoundline);
@@ -165,9 +165,9 @@ chooseorcfile (GtkWidget * widget, struct cs_callback *data)
   gtk_widget_show_all (fs);
   if (gtk_dialog_run (GTK_DIALOG (fs)) == GTK_RESPONSE_ACCEPT)
     {
-      g_string_assign (gui->prefs->csoundorcfile,
+      g_string_assign (Denemo.prefs.csoundorcfile,
 		       gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (fs)));
-      gtk_entry_set_text (GTK_ENTRY (entry), gui->prefs->csoundorcfile->str);
+      gtk_entry_set_text (GTK_ENTRY (entry), Denemo.prefs.csoundorcfile->str);
 
     }
   gtk_widget_destroy (fs);
