@@ -521,7 +521,7 @@ draw_staff (DenemoStaff * curstaffstruct, gint y,
   if (!blackgc)
     {
       blackgc = gcs_blackgc ();
-      yellowgc = gcs_yellowgc ();
+      yellowgc = gcs_slategraygc ();
     }
   if ((DenemoStaff *) si->currentstaff->data == curstaffstruct)
     gc = blackgc;
@@ -536,6 +536,7 @@ draw_staff (DenemoStaff * curstaffstruct, gint y,
 	    0, itp->clef, TRUE);
   memcpy (itp->keyaccs, curstaffstruct->leftmost_keyaccs, SEVENGINTS);
   x += si->maxkeywidth;
+
   draw_timesig (gui->pixmap, gc, gtk_style_get_font (itp->widget->style), x,
 		y, itp->time1 =
 		curstaffstruct->leftmost_time1context, itp->time2 =
@@ -570,6 +571,7 @@ draw_staff (DenemoStaff * curstaffstruct, gint y,
   while (itp->measurenum <= si->rightmeasurenum
 	 && itp->measurenum <= g_list_length (curstaffstruct->measures))
     {
+
       draw_measure (itp->curmeasure, x, y, gui, itp);
       x += GPOINTER_TO_INT (itp->mwidthiterator->data) + SPACE_FOR_BARLINE;
       itp->curmeasure = itp->curmeasure->next;
