@@ -85,42 +85,40 @@ get_fakechord (chord * ch)
 }
 
 void
-seperate_fakechord_elements (gchar *fakechord, DenemoObject *curObj)
+separate_fakechord_elements (gchar *fakechord, DenemoObject *curObj)
 {
-	
-  gint i = 0;
-	gboolean has_extension = FALSE;
-	gboolean has_pedal_bass = FALSE;
-	gchar tmp2;
-	GString *base = g_string_new("");
-	GString *extension = g_string_new("");
+  gboolean has_extension = FALSE;
+  gboolean has_pedal_bass = FALSE;
+  gchar tmp2;
+  GString *base = g_string_new("");
+  GString *extension = g_string_new("");
 
-		while (i<sizeof(fakechord)){
-		  tmp2 = (gchar *) fakechord[i];
-		  if ((tmp2 != ':') && (has_extension == FALSE))
-		  	g_string_sprintfa(base, "%c", fakechord[i]);
-		  if (tmp2 == ':')
-		  	has_extension = TRUE;
-	 	  if (has_extension)
-		  	g_string_sprintfa(extension, "%c", fakechord[i]);
-		  if (tmp2 = '/')
-		  	has_pedal_bass = TRUE;
-		i++;
-		}
+  do {
+    if ((*fakechord != ':') && (has_extension == FALSE))
+      g_string_sprintfa(base, "%c", *fakechord);
+    if (*fakechord == ':')
+      has_extension = TRUE;
+    if (has_extension)
+      g_string_sprintfa(extension, "%c", *fakechord);
+    if (*fakechord = '/')
+      has_pedal_bass = TRUE;// not used!!!
+  } while (*++fakechord);
 	
-	printf("\nthe base chord is %s\n", base->str);
-	printf("\nthe chord extension is %s\n", extension->str);
+  //g_print("\nthe base chord is %s\n", base->str);
+  //g_print("\nthe chord extension is %s\n", extension->str);
 
  
-  if (curObj && curObj->type == CHORD)
-         ((chord *) curObj->object)->is_fakechord = TRUE;
-	((chord *) curObj->object)->fakechord = base;
-        if (has_extension)
-		((chord *) curObj->object)->fakechord_extension = extension;
-	else 
-		((chord *) curObj->object)->fakechord_extension = NULL;
-	has_extension = FALSE;
-	has_pedal_bass = FALSE;
+  if (curObj && curObj->type == CHORD) {
+    ((chord *) curObj->object)->is_fakechord = TRUE;
+    ((chord *) curObj->object)->fakechord = base;
+    if (has_extension)
+      ((chord *) curObj->object)->fakechord_extension = extension;
+    else {
+      g_string_free(extension, TRUE);
+      ((chord *) curObj->object)->fakechord_extension = NULL;
+    }
+  }
+  
 }
 
 
@@ -140,7 +138,7 @@ insertfakechord (GtkWidget * widget, gpointer data)
 	  DenemoObject *curObj = (DenemoObject *) si->currentobject ?
 	    (DenemoObject *) si->currentobject->data : NULL;
 	  gchar *fakechord = (gchar *) gtk_entry_get_text (GTK_ENTRY (cbdata->entry));
-	  seperate_fakechord_elements(fakechord, curObj);
+	  separate_fakechord_elements(fakechord, curObj);
 	  do
 	    {
 	      if (si->currentobject->next)
@@ -153,7 +151,7 @@ insertfakechord (GtkWidget * widget, gpointer data)
 	  while ((curObj != NULL) && (curObj->type != CHORD));
 
 	  si->has_fakechords = &null_info;
-	  si->haschanged = TRUE;
+	  gui->haschanged = TRUE;
   }
   else {
 	warningdialog("CLIPPY: There is no object here to attach a fakechord to.  May I suggest creating a staff with the harmonic rhythm in it to attach the fakechords to.");	 
