@@ -1018,8 +1018,8 @@ save_keymap_dialog (GtkWidget * widget, keymap * the_keymap)
 void
 save_standard_keymap_file_wrapper (GtkWidget * widget, DenemoGUI *gui)
 {
-  keymap * the_keymap = gui->prefs->the_keymap;
-  if(the_keymap != gui->prefs->standard_keymap) {
+  keymap * the_keymap = Denemo.prefs.the_keymap;
+  if(the_keymap != Denemo.prefs.standard_keymap) {
     warningdialog("You are trying to overwrite your standard keymap with one designed for a particular mode.\nUse \"Save as Alternate Keymap File\" for this if you really mean it\n");
     return;
   }
