@@ -34,7 +34,7 @@ struct callbackdata
   gint statusbar1_context_id;
   gint command_selected;
   gint keybinding_number_selected;
-  struct keymap *the_keymap;
+  keymap *the_keymap;
 };
 
 /**
@@ -46,7 +46,7 @@ set_binding_list (GtkWidget * commands_list, gint row, gint column,
 		  GdkEventButton * event, struct callbackdata *cbdata)
 {
   GList *iterator;
-  struct keybinding_info *ki;
+  KeybindingInfo *ki;
   gint i;
   gchar *rowtext[1];
   gchar *mods;
@@ -56,10 +56,12 @@ set_binding_list (GtkWidget * commands_list, gint row, gint column,
   for (iterator = cbdata->the_keymap->commands[row], i = 0; iterator;
        iterator = iterator->next, i++)
     {
-      ki = (struct keybinding_info *) iterator->data;
+      ki = (KeybindingInfo *) iterator->data;
       mods = NULL;
-      set_state(ki->state, &mods);
-      rowtext[0] = g_strdup_printf ("%s%s", mods ? _(mods) : "", _(gdk_keyval_name (ki->keyval)));
+      set_state (ki->state, &mods);
+      rowtext[0] =
+	g_strdup_printf ("%s%s", mods ? _(mods) : "",
+			 _(gdk_keyval_name (ki->keyval)));
       gtk_clist_append (GTK_CLIST (cbdata->binding_list), rowtext);
       g_free (rowtext[0]);
     }
@@ -102,7 +104,7 @@ jump (GtkWidget * kbd_window, GdkEventKey * event,
      they are. */
   if (event->keyval < GDK_Shift_L || event->keyval > GDK_Hyper_R)
     {
-      struct keybinding_info *ki;
+      KeybindingInfo *ki;
 
       if ((ki = lookup_keybinding (cbdata->the_keymap, event->keyval,
 				   event->state)))
@@ -127,7 +129,7 @@ jump (GtkWidget * kbd_window, GdkEventKey * event,
 /**
  * Add given binding to the keymap
  *
- */ 
+ */
 static void
 add (GtkWidget * kbd_window, GdkEventKey * event, struct callbackdata *cbdata)
 {
@@ -217,15 +219,14 @@ remove_binding (GtkWidget * button_remove_binding,
   if (cbdata->command_selected != -1
       && cbdata->keybinding_number_selected != -1)
     {
-      struct keybinding_info *ki;
+      KeybindingInfo *ki;
 
       ki =
-	(struct keybinding_info *) g_list_nth (cbdata->the_keymap->
-					       commands[cbdata->
-							command_selected],
-					       cbdata->
-					       keybinding_number_selected)->
-	data;
+	(KeybindingInfo *) g_list_nth (cbdata->the_keymap->
+				       commands[cbdata->
+						command_selected],
+				       cbdata->
+				       keybinding_number_selected)->data;
       remove_keybinding (cbdata->the_keymap, ki->keyval, ki->state);
       set_binding_list (cbdata->commands_list, cbdata->command_selected, 0,
 			NULL, cbdata);
@@ -237,7 +238,7 @@ remove_binding (GtkWidget * button_remove_binding,
  * save to an alternative file
  */
 void
-configure_keyboard_dialog_OLD (GtkAction *action, struct scoreinfo *si)
+configure_keyboard_dialog_OLD (GtkAction * action, DenemoGUI * gui)
 {
   GtkWidget *kbd_window;
   GtkWidget *vbox3;
@@ -264,7 +265,7 @@ configure_keyboard_dialog_OLD (GtkAction *action, struct scoreinfo *si)
   GtkWidget *button_load;
   GtkWidget *button_load_from;
   GtkWidget *statusbar1;
-  struct keymap *the_keymap = si->prefs->the_keymap;
+  keymap *the_keymap = Denemo.prefs.the_keymap;
   GtkTooltips *tooltips;
   gint i;
   gchar *rowtext[1];
@@ -451,13 +452,13 @@ configure_keyboard_dialog_OLD (GtkAction *action, struct scoreinfo *si)
 			     GTK_OBJECT (kbd_window));
   gtk_signal_connect (GTK_OBJECT (button_ok_save), "clicked",
 		      GTK_SIGNAL_FUNC (save_standard_keymap_file_wrapper),
-		      the_keymap);
+		      gui);
   gtk_signal_connect_object (GTK_OBJECT (button_ok_save), "clicked",
 			     GTK_SIGNAL_FUNC (gtk_widget_destroy),
 			     GTK_OBJECT (kbd_window));
   gtk_signal_connect (GTK_OBJECT (button_save), "clicked",
 		      GTK_SIGNAL_FUNC (save_standard_keymap_file_wrapper),
-		      the_keymap);
+		      gui);
   gtk_signal_connect (GTK_OBJECT (button_save_as), "clicked",
 		      GTK_SIGNAL_FUNC (save_keymap_dialog), the_keymap);
   gtk_signal_connect (GTK_OBJECT (button_load), "clicked",
@@ -474,129 +475,141 @@ configure_keyboard_dialog_OLD (GtkAction *action, struct scoreinfo *si)
 
 struct cbdata2
 {
-  struct keymap* keymap;
-  GtkTreeView* treeview;
-  GtkComboBox* category;
-  GtkComboBox* command;
-  GtkDialog* dialog;
+  keymap *thekeymap;
+  GtkTreeView *treeview;
+  GtkComboBox *category;
+  GtkComboBox *command;
+  GtkDialog *dialog;
 };
 
 /**
  * Callback invoked when the category is changed
  */
-static void category_changed(GtkComboBox* category, struct cbdata2* cbdata)
+static void
+category_changed (GtkComboBox * category, struct cbdata2 *cbdata)
 {
-  gint a = gtk_combo_box_get_active(category);
-  gchar* cat = kbd_categories[a];
+  gint a = gtk_combo_box_get_active (category);
+  gchar *cat = kbd_categories[a];
   gint i;
 
-  GtkListStore* model = (GtkListStore*)gtk_combo_box_get_model(cbdata->command);
-  gtk_list_store_clear(model);
+  GtkListStore *model =
+    (GtkListStore *) gtk_combo_box_get_model (cbdata->command);
+  gtk_list_store_clear (model);
 
   for (i = 0; i < unmenued_commands_length; i++)
     {
-      if (strcmp(unmenued_commands[i].category, cat) == 0)
+      if (strcmp (unmenued_commands[i].category, cat) == 0)
 	{
-	  gtk_combo_box_append_text(cbdata->command, _(unmenued_commands[i].name));
+	  gtk_combo_box_append_text (cbdata->command,
+				     _(unmenued_commands[i].name));
 	}
     }
-  gtk_combo_box_set_active(cbdata->command, 0);
+  gtk_combo_box_set_active (cbdata->command, 0);
 }
 
 /**
  * Callback invoked when the command is changed.
  * Updates the list of keybindings for the selected command.
  */
-static void command_changed(GtkComboBox* command, struct cbdata2* cbdata)
+static void
+command_changed (GtkComboBox * command, struct cbdata2 *cbdata)
 {
-  gchar* name;
+  gchar *name;
   GtkTreeIter iter;
   int i;
 
-  name = gtk_combo_box_get_active_text(command);
-  GtkListStore *list_store = (GtkListStore*)gtk_tree_view_get_model(cbdata->treeview);
-  gtk_list_store_clear(list_store);
+  name = gtk_combo_box_get_active_text (command);
+  GtkListStore *list_store =
+    (GtkListStore *) gtk_tree_view_get_model (cbdata->treeview);
+  gtk_list_store_clear (list_store);
 
-  for (i=0; i<denemo_commands_size; i++)
+  for (i = 0; i < denemo_commands_size; i++)
     {
-      if (strcmp(denemo_commands[i].name, name) == 0)
+      if (strcmp (denemo_commands[i].name, name) == 0)
 	{
-	  GList* c;
-	  for (c = cbdata->keymap->commands[i]; c != NULL; c = g_list_next(c))
+	  GList *c;
+	  for (c = cbdata->thekeymap->commands[i]; c != NULL;
+	       c = g_list_next (c))
 	    {
-	      struct keybinding_info *ki = (struct keybinding_info *)c->data;
+	      KeybindingInfo *ki = (KeybindingInfo *) c->data;
 	      gtk_list_store_append (list_store, &iter);
 	      gtk_list_store_set (list_store, &iter,
 				  COL_LABEL, gdk_keyval_name (ki->keyval),
-				  COL_COMMAND, denemo_commands[i].name,
-				  -1);
+				  COL_COMMAND, denemo_commands[i].name, -1);
 	    }
 	}
     }
 
 }
 
-static void validate_keymap_name(GtkEntry *entry, GtkDialog* dialog)
+static void
+validate_keymap_name (GtkEntry * entry, GtkDialog * dialog)
 {
-  const gchar* name = gtk_entry_get_text(GTK_ENTRY(entry));
-  gtk_dialog_set_response_sensitive(GTK_DIALOG(dialog),
-				    GTK_RESPONSE_ACCEPT, strlen(name) > 0);
+  const gchar *name = gtk_entry_get_text (GTK_ENTRY (entry));
+  gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog),
+				     GTK_RESPONSE_ACCEPT, strlen (name) > 0);
 }
 
 /**
  * Save the selected keymap under a different name
  */
-static void save_keymap_as(GtkButton* button, struct cbdata2* cbdata)
+static void
+save_keymap_as (GtkButton * button, struct cbdata2 *cbdata)
 {
-  GtkWidget* dialog;
-  GtkWidget* box;
-  GtkWidget* label;
-  GtkWidget* entry;
+  GtkWidget *dialog;
+  GtkWidget *box;
+  GtkWidget *label;
+  GtkWidget *entry;
 
   dialog = gtk_dialog_new_with_buttons (_("Save keyboard shortcut"),
-					GTK_WINDOW(cbdata->dialog),
-					(GtkDialogFlags)(GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT),
-                                        GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
+					GTK_WINDOW (cbdata->dialog),
+					(GtkDialogFlags) (GTK_DIALOG_MODAL |
+							  GTK_DIALOG_DESTROY_WITH_PARENT),
+					GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
 					GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
 					NULL);
 
-  gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_ACCEPT);
-  gtk_dialog_set_response_sensitive(GTK_DIALOG(dialog), GTK_RESPONSE_ACCEPT, FALSE);
+  gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
+  gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT,
+				     FALSE);
 
   box = gtk_hbox_new (FALSE, 8);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG(dialog)->vbox), box, TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), box, TRUE, TRUE,
+		      0);
   gtk_container_set_border_width (GTK_CONTAINER (box), 12);
 
   label = gtk_label_new_with_mnemonic (_("_Name:"));
   gtk_box_pack_start (GTK_BOX (box), label, FALSE, TRUE, 0);
 
-  entry = gtk_entry_new();
+  entry = gtk_entry_new ();
   gtk_box_pack_start (GTK_BOX (box), entry, FALSE, TRUE, 0);
-  gtk_label_set_mnemonic_widget(GTK_LABEL(label), entry);
-  gtk_entry_set_activates_default(GTK_ENTRY(entry), TRUE);
-  g_signal_connect(entry, "changed", G_CALLBACK (validate_keymap_name), dialog);
+  gtk_label_set_mnemonic_widget (GTK_LABEL (label), entry);
+  gtk_entry_set_activates_default (GTK_ENTRY (entry), TRUE);
+  g_signal_connect (entry, "changed", G_CALLBACK (validate_keymap_name),
+		    dialog);
 
-  gtk_widget_show_all(dialog);
+  gtk_widget_show_all (dialog);
 
-  if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT)
+  if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
     {
-      const gchar* name = gtk_entry_get_text(GTK_ENTRY(entry));
-      gchar* file_name = g_strconcat(name, ".keymaprc", NULL);
-      gchar* path = g_build_filename(locatedotdenemo(), file_name, NULL);
+      const gchar *name = gtk_entry_get_text (GTK_ENTRY (entry));
+      gchar *file_name = g_strconcat (name, ".keymaprc", NULL);
+      gchar *path = g_build_filename (locatedotdenemo (), file_name, NULL);
 
       // TODO: Actually copy the keymap
 
-      g_print("%s\n", path);
-      g_free(file_name);
-      g_free(path);
+      g_print ("%s\n", path);
+      g_free (file_name);
+      g_free (path);
     }
 
-  gtk_widget_destroy(dialog);
+  gtk_widget_destroy (dialog);
 
 }
 
 
-static void change_scheme(GtkComboBox* scheme, gpointer data)
+static void
+change_scheme (GtkComboBox * scheme, gpointer data)
 {
   // TODO: load the keymap
   // TODO: disable delete for Default keymap
@@ -606,32 +619,35 @@ static void change_scheme(GtkComboBox* scheme, gpointer data)
  * Populate the combo with the names of all .keymaprc-files found under ~/.denemo
  * TODO: Include keymaps from /etc/denemo
  */
-static void update_keymaps_list(GtkComboBox* combo)
+static void
+update_keymaps_list (GtkComboBox * combo)
 {
-  GtkListStore* model = (GtkListStore*)gtk_combo_box_get_model(combo);
-  gtk_list_store_clear(model);
-  gtk_combo_box_append_text(GTK_COMBO_BOX(combo), "Default");
+  GtkListStore *model = (GtkListStore *) gtk_combo_box_get_model (combo);
+  gtk_list_store_clear (model);
+  gtk_combo_box_append_text (GTK_COMBO_BOX (combo), "Default");
 
-  const gchar* dotdenemo = locatedotdenemo();
-  GDir* dir = g_dir_open(dotdenemo, 0, NULL);
-  g_assert(dir != NULL);
+  const gchar *dotdenemo = locatedotdenemo ();
+  if(dotdenemo==NULL)
+    return;
+  GDir *dir = g_dir_open (dotdenemo, 0, NULL);
+  g_assert (dir != NULL);
 
-  const gchar* file = NULL;
-  while ((file = g_dir_read_name(dir)) != NULL)
+  const gchar *file = NULL;
+  while ((file = g_dir_read_name (dir)) != NULL)
     {
-      if (g_str_has_suffix(file, ".keymaprc"))
+      if (g_str_has_suffix (file, ".keymaprc"))
 	{
-          gchar* name = g_strndup(file, strlen(file) - 9);
-	  gtk_combo_box_append_text(GTK_COMBO_BOX(combo), name);
-          g_free(name);
+	  gchar *name = g_strndup (file, strlen (file) - 9);
+	  gtk_combo_box_append_text (GTK_COMBO_BOX (combo), name);
+	  g_free (name);
 	}
     }
-  g_dir_close(dir);
+  g_dir_close (dir);
 }
 
 
 void
-configure_keyboard_dialog (GtkAction *action, struct scoreinfo *si)
+configure_keyboard_dialog (GtkAction * action, DenemoGUI * gui)
 {
   GtkWidget *dialog;
   GtkWidget *vbox;
@@ -651,13 +667,15 @@ configure_keyboard_dialog (GtkAction *action, struct scoreinfo *si)
   gint i;
 
   dialog = gtk_dialog_new_with_buttons (_("Keyboard shortcuts"),
-					GTK_WINDOW(si->window),
-					(GtkDialogFlags)(GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT),
+					GTK_WINDOW (gui->window),
+					(GtkDialogFlags) (GTK_DIALOG_MODAL |
+							  GTK_DIALOG_DESTROY_WITH_PARENT),
 					GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 					NULL);
 
   vbox = gtk_vbox_new (FALSE, 8);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG(dialog)->vbox), vbox, TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), vbox, TRUE, TRUE,
+		      0);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
 
   table = gtk_table_new (4, 4, FALSE);
@@ -667,118 +685,121 @@ configure_keyboard_dialog (GtkAction *action, struct scoreinfo *si)
 
   hseparator = gtk_hseparator_new ();
   gtk_table_attach (GTK_TABLE (table), hseparator, 0, 4, 1, 2,
-                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-                    (GtkAttachOptions) (GTK_FILL), 0, 0);
+		    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+		    (GtkAttachOptions) (GTK_FILL), 0, 0);
 
   label = gtk_label_new_with_mnemonic (_("_Scheme:"));
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
-                    (GtkAttachOptions) (GTK_FILL),
-                    (GtkAttachOptions) (0), 0, 0);
+		    (GtkAttachOptions) (GTK_FILL),
+		    (GtkAttachOptions) (0), 0, 0);
   gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
   scheme = gtk_combo_box_new_text ();
-  update_keymaps_list(GTK_COMBO_BOX(scheme));
+  update_keymaps_list (GTK_COMBO_BOX (scheme));
   gtk_table_attach (GTK_TABLE (table), scheme, 1, 2, 0, 1,
-                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-                    (GtkAttachOptions) (GTK_FILL), 0, 0);
+		    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+		    (GtkAttachOptions) (GTK_FILL), 0, 0);
 
-  gtk_combo_box_set_active(GTK_COMBO_BOX(scheme), 0);
-  gtk_label_set_mnemonic_widget(GTK_LABEL(label), scheme);
-  g_signal_connect(scheme, "changed", G_CALLBACK (change_scheme), NULL);
+  gtk_combo_box_set_active (GTK_COMBO_BOX (scheme), 0);
+  gtk_label_set_mnemonic_widget (GTK_LABEL (label), scheme);
+  g_signal_connect (scheme, "changed", G_CALLBACK (change_scheme), NULL);
 
   button_save = gtk_button_new_from_stock (GTK_STOCK_SAVE_AS);
   gtk_table_attach (GTK_TABLE (table), button_save, 2, 3, 0, 1,
-                    (GtkAttachOptions) (0),
-                    (GtkAttachOptions) (0), 0, 0);
+		    (GtkAttachOptions) (0), (GtkAttachOptions) (0), 0, 0);
 
   button = gtk_button_new_from_stock (GTK_STOCK_DELETE);
   gtk_table_attach (GTK_TABLE (table), button, 3, 4, 0, 1,
-                    (GtkAttachOptions) (0),
-		    (GtkAttachOptions) (0), 0, 0);
-  gtk_widget_set_sensitive(button, FALSE);
+		    (GtkAttachOptions) (0), (GtkAttachOptions) (0), 0, 0);
+  gtk_widget_set_sensitive (button, FALSE);
 
   label = gtk_label_new_with_mnemonic (_("C_ategory:"));
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3,
-                    (GtkAttachOptions) (GTK_FILL),
-                    (GtkAttachOptions) (0), 0, 0);
+		    (GtkAttachOptions) (GTK_FILL),
+		    (GtkAttachOptions) (0), 0, 0);
   gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
   // FIXME: Does not work with translated command names
   category = gtk_combo_box_new_text ();
   gtk_table_attach (GTK_TABLE (table), category, 1, 4, 2, 3,
-                    (GtkAttachOptions) (GTK_FILL),
+		    (GtkAttachOptions) (GTK_FILL),
 		    (GtkAttachOptions) (GTK_FILL), 0, 0);
-  gtk_label_set_mnemonic_widget(GTK_LABEL(label), category);
+  gtk_label_set_mnemonic_widget (GTK_LABEL (label), category);
 
   for (i = 0; i < kbd_categories_length; i++)
     {
-      gtk_combo_box_append_text(GTK_COMBO_BOX(category), _(kbd_categories[i]));
+      gtk_combo_box_append_text (GTK_COMBO_BOX (category),
+				 _(kbd_categories[i]));
     }
 
   label = gtk_label_new_with_mnemonic (_("_Command:"));
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 3, 4,
-                    (GtkAttachOptions) (GTK_FILL),
-                    (GtkAttachOptions) (0), 0, 0);
+		    (GtkAttachOptions) (GTK_FILL),
+		    (GtkAttachOptions) (0), 0, 0);
   gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
   // FIXME: Does not work with translated command names
   command = gtk_combo_box_new_text ();
   gtk_table_attach (GTK_TABLE (table), command, 1, 4, 3, 4,
-                    (GtkAttachOptions) (GTK_FILL),
+		    (GtkAttachOptions) (GTK_FILL),
 		    (GtkAttachOptions) (GTK_FILL), 0, 0);
-  gtk_label_set_mnemonic_widget(GTK_LABEL(label), command);
+  gtk_label_set_mnemonic_widget (GTK_LABEL (label), command);
 
   scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
   gtk_box_pack_start (GTK_BOX (vbox), scrolledwindow, TRUE, TRUE, 0);
-  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow), GTK_SHADOW_IN);
-  gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW (scrolledwindow),
-				 GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow),
+				       GTK_SHADOW_IN);
+  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow),
+				  GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
   list_store = gtk_list_store_new (2, G_TYPE_STRING,	/* binding label */
 				   G_TYPE_STRING);	/* command name */
 
 
-  treeview = gtk_tree_view_new_with_model (GTK_TREE_MODEL(list_store));
-  gtk_widget_set_size_request(treeview, -1, 150);
+  treeview = gtk_tree_view_new_with_model (GTK_TREE_MODEL (list_store));
+  gtk_widget_set_size_request (treeview, -1, 150);
   renderer = gtk_cell_renderer_text_new ();
 
   gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (treeview), -1,
 					       "Shortcuts", renderer,
-					       "text", COL_LABEL,
-					       NULL);
+					       "text", COL_LABEL, NULL);
 
   gtk_container_add (GTK_CONTAINER (scrolledwindow), treeview);
 
   hbuttonbox = gtk_hbutton_box_new ();
   gtk_box_pack_start (GTK_BOX (vbox), hbuttonbox, FALSE, TRUE, 0);
-  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_START);
+  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox),
+			     GTK_BUTTONBOX_START);
   gtk_box_set_spacing (GTK_BOX (hbuttonbox), 8);
 
   button = gtk_button_new_from_stock (GTK_STOCK_ADD);
   gtk_container_add (GTK_CONTAINER (hbuttonbox), button);
-  
+
   button = gtk_button_new_from_stock (GTK_STOCK_REMOVE);
   gtk_container_add (GTK_CONTAINER (hbuttonbox), button);
-  gtk_widget_set_sensitive(button, FALSE);
+  gtk_widget_set_sensitive (button, FALSE);
 
   button = gtk_button_new_from_stock (GTK_STOCK_FIND);
   gtk_container_add (GTK_CONTAINER (hbuttonbox), button);
 
 
   struct cbdata2 cbdata;
-  cbdata.command = GTK_COMBO_BOX(command);
-  cbdata.category = GTK_COMBO_BOX(category);
-  cbdata.treeview = GTK_TREE_VIEW(treeview);
-  cbdata.keymap = si->prefs->the_keymap;
-  cbdata.dialog = GTK_DIALOG(dialog);
+  cbdata.command = GTK_COMBO_BOX (command);
+  cbdata.category = GTK_COMBO_BOX (category);
+  cbdata.treeview = GTK_TREE_VIEW (treeview);
+  cbdata.thekeymap = Denemo.prefs.the_keymap;
+  cbdata.dialog = GTK_DIALOG (dialog);
 
-  g_signal_connect(category, "changed", G_CALLBACK (category_changed), &cbdata);
-  g_signal_connect(command, "changed", G_CALLBACK (command_changed), &cbdata);
-  g_signal_connect(button_save, "clicked", G_CALLBACK (save_keymap_as), &cbdata);
+  g_signal_connect (category, "changed", G_CALLBACK (category_changed),
+		    &cbdata);
+  g_signal_connect (command, "changed", G_CALLBACK (command_changed),
+		    &cbdata);
+  g_signal_connect (button_save, "clicked", G_CALLBACK (save_keymap_as),
+		    &cbdata);
 
-  gtk_combo_box_set_active(GTK_COMBO_BOX(category), 0);
+  gtk_combo_box_set_active (GTK_COMBO_BOX (category), 0);
 
-  gtk_widget_show_all(dialog);
-  gtk_dialog_run(GTK_DIALOG(dialog));
-  gtk_widget_destroy(dialog);
+  gtk_widget_show_all (dialog);
+  gtk_dialog_run (GTK_DIALOG (dialog));
+  gtk_widget_destroy (dialog);
 }
