@@ -33,7 +33,7 @@ scorearea_keypress_event (GtkWidget * widget, GdkEventKey * event,
   /* Look up the keystroke in the keymap and execute the appropriate
    * function */
 
-  if ((ki = lookup_keybinding (gui->prefs->the_keymap, event->keyval,
+  if ((ki = lookup_keybinding (Denemo.prefs.the_keymap, event->keyval,
 			       event->state)))
     {
 
@@ -565,14 +565,14 @@ deletepreviousobject(DenemoGUI * gui)
       }
     }
   /* if you are following a rhythmic pattern then backup the pattern */
-#define g  (gui->si->rstep)
+#define g  (gui->rstep)
   if((gui->mode&(INPUTEDIT) && g)) 
     {
-#define CURRP ((RhythmPattern *)gui->si->currhythm->data) 
+#define CURRP ((RhythmPattern *)gui->currhythm->data) 
       g = g->prev; /* list is circular - should we stop at beginning? */
       if(((RhythmElement*)g->data)->icon) {
 	GtkWidget *label = LABEL(CURRP->button);
-	gtk_label_set_markup(label,((RhythmElement*)g->data)->icon);
+	gtk_label_set_markup(GTK_LABEL(label),((RhythmElement*)g->data)->icon);
       }
 #undef CURRP
 #undef g
