@@ -184,13 +184,15 @@ insert_keysig (GtkWidget * widget, gpointer data)
 	    {
 	      curmeasure = g_list_nth (firstmeasurenode (curstaff),
 				       si->currentmeasurenum - 1);
-	      curmeasure->data = g_list_append ((objnode *) curmeasure->data,
-						dnm_newkeyobj ((tokey - mode),
-							       isminor, mode));
-	      if (curmeasure == si->currentmeasure)
-		si->currentobject =
-		  g_list_nth ((objnode *) curmeasure->data, si->cursor_x);
-	      showwhichaccidentalswholestaff ((DenemoStaff *) curstaff->data);
+	      if(curmeasure) {
+		curmeasure->data = g_list_append ((objnode *) curmeasure->data,
+						  dnm_newkeyobj ((tokey - mode),
+								 isminor, mode));
+		if (curmeasure == si->currentmeasure)
+		  si->currentobject =
+		    g_list_nth ((objnode *) curmeasure->data, si->cursor_x);
+		showwhichaccidentalswholestaff ((DenemoStaff *) curstaff->data);
+	      }
 	    }			/* End for */
 	}			/* End if */
       else
