@@ -1550,7 +1550,7 @@ lily_text_change (DenemoGUI *gui)
 void
 create_text_display (DenemoGUI *gui)
 {
-  updatescoreinfo (gui->si); // RRR
+  updatescoreinfo (gui); // RRR
   return;
 }
 #endif
