@@ -37,7 +37,7 @@
 #include <glib/gstdio.h>
 #include "midiseq.h"
 
-GList *displays = NULL;
+struct DenemoRoot Denemo;
 midi_seq *sq;
 #include "view.h"
 #include "exportxml.h"
@@ -100,17 +100,26 @@ load_accels () {
       gtk_accel_map_load (filename);
     else {
       gtk_accel_map_load (systemwide);
-      gtk_accel_map_save (filename);
+      //gtk_accel_map_save (filename);
     }
   } else
     gtk_accel_map_load (systemwide);
    if(filename) 
      g_free(filename);
+
+   filename = dotdenemo?g_build_filename(locatedotdenemo(), EXTRA_ACCELS, NULL):NULL;
+   if(filename) {
+     if(g_file_test(filename,  G_FILE_TEST_EXISTS))
+       gtk_accel_map_load (filename);
+   }
+   if(filename) 
+     g_free(filename);
 }
 static void
 register_stock_icon (GtkIconFactory * icon_factory, const gchar * stock_id,
                      const gchar * file)
 {
+  static gboolean warned;
   GtkIconSet *icon_set;
   GdkPixbuf *pixbuf;
   GError *error = NULL;
@@ -118,19 +127,21 @@ register_stock_icon (GtkIconFactory * icon_factory, const gchar * stock_id,
 
   g_debug ("path is %s\n", path);
   pixbuf = gdk_pixbuf_new_from_file (path, &error);
-
+  if(!warned)
   if(error != NULL)
     {
-      g_error (_("Could not load specified pixbuf:\n%s\n"),
+      g_warning (_("Could not load specified pixbuf:\n%s\n"),
                  error->message);
       g_error_free (error);
+      warningdialog("some icons will not display properly, but program will run ok.");
+      warned = TRUE;
     }
-  g_assert (pixbuf != NULL);
-
-  icon_set = gtk_icon_set_new_from_pixbuf (pixbuf);
-  g_object_unref (pixbuf);
-  gtk_icon_factory_add (icon_factory, stock_id, icon_set);
-  g_free (path);
+  if(pixbuf != NULL) {
+    icon_set = gtk_icon_set_new_from_pixbuf (pixbuf);
+    g_object_unref (pixbuf);
+    gtk_icon_factory_add (icon_factory, stock_id, icon_set);
+    g_free (path);
+  } 
 }
 
 static void
@@ -144,44 +155,41 @@ register_stock_items ()
 
   icon_factory = gtk_icon_factory_new ();
   gtk_icon_factory_add_default (icon_factory);
-
   register_stock_icon (icon_factory, "denemo-staccato", "staccato.svg");
   register_stock_icon (icon_factory, "denemo-staccatissimo",
-                       "staccatissimo.svg");
+		       "staccatissimo.svg");
   register_stock_icon (icon_factory, "denemo-marcato", "marcato.svg");
-  register_stock_icon (icon_factory, "denemo-accent", "accent.svg");
-
+  register_stock_icon (icon_factory, "denemo-accent", "accent.svg");	 
   register_stock_icon (icon_factory, "denemo-fermata", "fermata.svg");
   register_stock_icon (icon_factory, "denemo-tenuto", "tenuto.svg");
   register_stock_icon (icon_factory, "denemo-turn", "turn.svg");
   register_stock_icon (icon_factory, "denemo-reverse-turn",
-                       "reverse-turn.svg");
-
+		       "reverse-turn.svg");	 
   register_stock_icon (icon_factory, "denemo-trill", "trill.svg");
   register_stock_icon (icon_factory, "denemo-mordent", "mordent.svg");
   register_stock_icon (icon_factory, "denemo-up-bow", "upbow.svg");
   register_stock_icon (icon_factory, "denemo-down-bow", "downbow.svg");
-
+	 
   register_stock_icon (icon_factory, "denemo-rheel", "rheel.svg");
   register_stock_icon (icon_factory, "denemo-lheel", "lheel.svg");
   register_stock_icon (icon_factory, "denemo-rtoe", "rtoe.svg");
   register_stock_icon (icon_factory, "denemo-ltoe", "ltoe.svg");
-
+	 
   register_stock_icon (icon_factory, "denemo-whole-note", "icon-note-0.svg");
   register_stock_icon (icon_factory, "denemo-half-note", "icon-note-1.svg");
   register_stock_icon (icon_factory, "denemo-quarter-note",
-                       "icon-note-2.svg");
+		       "icon-note-2.svg");
   register_stock_icon (icon_factory, "denemo-eight-note", "icon-note-3.svg");
   register_stock_icon (icon_factory, "denemo-sixteenth-note",
-                       "icon-note-4.svg");
-
+		       "icon-note-4.svg");	 
   register_stock_icon (icon_factory, "denemo-whole-rest", "icon-rest-0.svg");
   register_stock_icon (icon_factory, "denemo-half-rest", "icon-rest-1.svg");
   register_stock_icon (icon_factory, "denemo-quarter-rest",
-                       "icon-rest-2.svg");
+		       "icon-rest-2.svg");
   register_stock_icon (icon_factory, "denemo-eight-rest", "icon-rest-3.svg");
   register_stock_icon (icon_factory, "denemo-sixteenth-rest",
-                       "icon-rest-4.svg");
+		       "icon-rest-4.svg");
+
   //New Ornaments added here, loding XBM's until svgs have been generated.
   register_stock_icon (icon_factory, "denemo-coda",
                        "feta26-scripts-coda.xbm");
@@ -215,7 +223,7 @@ register_stock_items ()
  * signal handler to be invoked when child processes _exit() without
  * having to wait for them 
  */
-void
+static void
 sigchld_handler (gint num)
 {
   sigset_t set, oldset;
@@ -306,26 +314,26 @@ denemo_signal_handler (int sig)
     already_in_segfault = 1;
 
 
-  g_print ("\nNo of displays : %d\n", g_list_length (displays));
+  g_print ("\nNo of displays : %d\n", g_list_length (Denemo.guis));
 
-  if (g_list_length (displays) == 1)
+  if (g_list_length (Denemo.guis) == 1)
     {
-      gui = (DenemoGUI *) displays->data;
+      gui = (DenemoGUI *) Denemo.guis->data;
       g_debug ("si is %p", gui);
       gchar *filename = g_build_filename(locatedotdenemo (), 
                                          "crashrecovery.denemo", NULL);
 
       if (gui->si->lily_file)
-        exportlilypond (filename, gui->si, 0, 0);
+        exportlilypond (filename, gui, 0, 0, 1);
       else
-        exportXML (filename, gui->si, 0, 0);
+        exportXML (filename, gui, 0, 0);
 
 
     }
   else
     {
       int i = 0;
-      for (tmp = displays; tmp && g_list_length (tmp) > 1; tmp = tmp->next)
+      for (tmp = Denemo.guis; tmp && g_list_length (tmp) > 1; tmp = tmp->next)
         {
           gui = (DenemoGUI *) tmp->data;
           gchar *filename = g_build_filename(locatedotdenemo (), 
@@ -335,9 +343,9 @@ denemo_signal_handler (int sig)
           strncat (filename, t, strlen (t));
           strcat (filename, ".denemo");
           if (gui->si->lily_file)
-            exportlilypond (filename, gui->si, 0, 0);
+            exportlilypond (filename, gui, 0, 0, 1);
           else
-            exportXML (filename, gui->si, 0, 0);
+            exportXML (filename, gui, 0, 0);
           i++;
         }
     }
@@ -436,7 +444,7 @@ COPYING for details.\n\n");
       else if (opts == 's')
         {
           g_print (copytext);
-          silentconversion (argv[optind], gui->si);
+          silentconversion (argv[optind], gui);
           exit (0);
         }
       else if (opts == 'v')
@@ -533,7 +541,7 @@ COPYING for details.\n\n");
               break;
             case GTK_RESPONSE_CANCEL:
               gui->window = NULL;
-              result = importXML (name, gui->si);
+              result = importXML (name, gui, REPLACE_SCORE);
               if (result != -1)
                 file_saveas (gui, FALSE);
               else
@@ -574,10 +582,10 @@ COPYING for details.\n\n");
 int
 openfile (gchar * name)
 {
-  GList *tmp = g_list_nth (displays, 0);
+  GList *tmp = g_list_nth (Denemo.guis, 0);
 
   DenemoGUI *gui = (DenemoGUI *) tmp->data;
-  gint result = open_for_real (name, gui, FALSE);
+  gint result = open_for_real (name, gui, FALSE, FALSE);
   //gui->si->readonly = FALSE;
   //si->readonly = TRUE;
   return result;
