@@ -26,7 +26,7 @@ offset_from_height (gdouble height, enum clefs clef)
     {
     case DENEMO_TREBLE_CLEF:
       R (10);
-      break;			/* This break and the ones following are probably gratuitous.  */
+      break;
     case DENEMO_BASS_CLEF:
       R (-2);
       break;
@@ -48,38 +48,38 @@ offset_from_height (gdouble height, enum clefs clef)
 }
 
 /**
- * Set the cursors y position from a mouse click
+ * Set the cursor's y position from a mouse click
  *
  */
 void
 set_cursor_y_from_click (DenemoGUI * gui, gdouble y)
 {
   /* Click height relative to the top of the staff.  */
-  float click_height;
+  gdouble click_height;
   gint staffs_from_top;
-
-  gtk_widget_queue_draw (gui->scorearea);//??????
-  staffs_from_top = gui->si->currentstaffnum - gui->si->top_staff;
-  // this takes account of staff->space_above and below...
-
+  staffs_from_top = 0;
   GList *curstaff;
   DenemoStaff *staff;
   gint extra_space = 0;
   for(  curstaff = g_list_nth(gui->si->thescore,gui->si->top_staff-1) ; curstaff;curstaff=curstaff->next) {
+    //    g_print("extra space %d\n", extra_space);
     staff = (DenemoStaff *) curstaff->data;
-    extra_space += (staff->space_above );
+    if(staff->voicenumber == 1)
+      extra_space += (staff->space_above );
     if(curstaff == gui->si->currentstaff)
       break;
-    extra_space += (staff->space_below + staff->haslyrics?LYRICS_HEIGHT:0);
+    if(staff->voicenumber == 1){
+      // FIXME this cannot work, different amounts of space_xxx may be stored in different voices
+      extra_space += ((staffs_from_top?staff->space_below:0) + (staff->haslyrics?LYRICS_HEIGHT:0));
+      staffs_from_top++;
+    }
 
   }
-  //????????????
-  //extra_space -=   (staff->space_below + staff->haslyrics?LYRICS_HEIGHT:0);
-  // g_print("Check %p and %p\n", gui->si->currentstaff, g_list_nth(gui->si->thescore,gui->si->currentstaffnum - gui->si->top_staff)); 
-  //g_print("Extra space %d\n",extra_space);
 
   click_height =
     y - (gui->si->staffspace * staffs_from_top + gui->si->staffspace / 4 + extra_space);
+  //  g_print("top staff is %d total %d staffs from top is %d click %f\n", gui->si->top_staff, extra_space, staffs_from_top, click_height);
+
   gui->si->cursor_y =
     offset_from_height (click_height, (enum clefs) gui->si->cursorclef);
   gui->si->staffletter_y = offsettonumber (gui->si->cursor_y);
@@ -93,7 +93,7 @@ struct placement_info
   objnode *the_obj;
 };
 
-/* find which staff in si the height y lies in, return the staff number */
+/* find which staff in si the height y lies in, return the staff number (not counting non-primary staffs ie voices) */
 
 static gint staff_at (gint y, DenemoScore *si) {
   GList *curstaff;
@@ -101,9 +101,11 @@ static gint staff_at (gint y, DenemoScore *si) {
   gint count;
   for(curstaff = g_list_nth(si->thescore, si->top_staff-1), count=0; curstaff && y>space;curstaff=curstaff->next) {
     DenemoStaff *staff = (DenemoStaff *) curstaff->data;
+
     count++;
-    space += (staff)->space_above +
-      (staff)->space_below + si->staffspace; 
+    if(staff->voicenumber == 1)
+      space += (staff)->space_above +
+	(staff)->space_below + si->staffspace; 
     //g_print("y %d and space %d count = %d\n",y,space, count);
   } 
   if(y<=1)
@@ -124,13 +126,6 @@ get_placement_from_coordinates (struct placement_info *pi,
   objnode *obj_iterator;
   gint x_to_explain = (gint) (x);
 
-  /* Calculate pi->staff_number, but don't go past si->bottom_staff.
-     (It can happen if there are too few staffs to fill the drawing area
-     from top to bottom.)  */
-//FIXME broken when space_above, below as it assumes si->staffspace for each staff
-  pi->staff_number = MIN ((si->top_staff
-			   + ((gint) y) / si->staffspace), si->bottom_staff);
-  
   pi->staff_number = staff_at((gint)y, si);
 /*   g_print("get staff number %d\n",pi->staff_number); */
   pi->measure_number = si->leftmeasurenum;
@@ -197,7 +192,7 @@ get_placement_from_coordinates (struct placement_info *pi,
  */
 gint
 scorearea_button_press (GtkWidget * widget, GdkEventButton * event,
-			  gpointer data)
+			gpointer data)
 {
   struct placement_info pi;
   DenemoGUI *gui = (DenemoGUI *) data;
@@ -207,111 +202,25 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event,
     get_placement_from_coordinates (&pi, event->x, event->y, gui->si);
   if (pi.the_measure != NULL){ /*don't place cursor in a place that is not there*/
 	 
-	  gui->si->currentstaffnum = pi.staff_number;
-	  gui->si->currentstaff = pi.the_staff;
-	  gui->si->currentmeasurenum = pi.measure_number;
-	  gui->si->currentmeasure = pi.the_measure;
-	  gui->si->currentobject = pi.the_obj;
-	  gui->si->cursor_x = pi.cursor_x;
- 	  gui->si->cursor_appending
-	    =
-	    (gui->si->cursor_x ==
-	     (gint) (g_list_length ((objnode *) gui->si->currentmeasure->data)));
-	  
-  
-	  /* Quickly redraw to reset si->cursorclef.  */
-	  gtk_widget_queue_draw (gui->scorearea);
-	  set_cursor_y_from_click (gui, event->y);
-	  if(!(gui->mode&INPUTCLASSIC)) {
-	    if(gui->si->markstaffnum)
-	      unset_mark(gui);
-	    else
-	      set_mark(gui);
-	  }
-	  
-  gchar *selection;
-  if(gui->si->currentobject) {
-    DenemoObject *curObj = gui->si->currentobject->data;
-    switch(curObj->type) {
-    case CHORD:
-      selection = g_strdup_printf("Note/rest %s%s%s%s%s%s%s%s",((chord *) curObj->object)->slur_begin_p?", begin slur":"",
-				  ((chord *) curObj->object)->slur_end_p?", end slur":"",
-				  ((chord *) curObj->object)->is_tied?", tied":"",
-				  ((chord *) curObj->object)->crescendo_begin_p?", begin cresc.":"",
-				  ((chord *) curObj->object)->crescendo_end_p?", end cresc.":"",
-				  ((chord *) curObj->object)->diminuendo_begin_p?", begin dim.":"",
-				  ((chord *) curObj->object)->diminuendo_end_p?", end dim.":"",
-				  ((chord *) curObj->object)->is_grace?", grace note":""
- );
-      break;
+    gui->si->currentstaffnum = pi.staff_number;
+    gui->si->currentstaff = pi.the_staff;
+    gui->si->currentmeasurenum = pi.measure_number;
+    gui->si->currentmeasure = pi.the_measure;
+    gui->si->currentobject = pi.the_obj;
+    gui->si->cursor_x = pi.cursor_x;
+    gui->si->cursor_appending
+      =
+      (gui->si->cursor_x ==
+       (gint) (g_list_length ((objnode *) gui->si->currentmeasure->data)));
+    set_cursor_y_from_click (gui, event->y);
 
-    case TUPOPEN:
-      selection = g_strdup_printf("Tuplet %d/%d", 	((tupopen *) curObj->object)->numerator,
-				  ((tupopen *) curObj->object)->denominator);
-      break;
-    case TUPCLOSE: 
-      selection = g_strdup_printf("End tuplet");
-	break;
-  case CLEF:
-selection = g_strdup_printf("clef change");
-break;
-  case TIMESIG:
-selection = g_strdup_printf("time signature change");
-break;
-  case KEYSIG:
-selection = g_strdup_printf("key signature change");
-break;
-  case BARLINE:
-    selection = g_strdup_printf("special barline type %d", 	((barline *) curObj->object)->type);// FIXME names for these
-break;
-  case STEMDIRECTIVE:
-selection = g_strdup_printf("stem directive: %s",((stemdirective *) curObj->object)->type==DENEMO_STEMDOWN?
-			    "stem down":((stemdirective *) curObj->object)->type==DENEMO_STEMUP?"stem up":
-			    "normal stemming");
-break;
-  case MEASUREBREAK:
-selection = g_strdup_printf("measurebreak");
-break;
-  case STAFFBREAK:
-selection = g_strdup_printf("staffbreak");
-break;
-  case DYNAMIC:
-selection = g_strdup_printf("Dynamic: %s", ((dynamic *) curObj->object)->type->str  );
-break;
-  case GRACE_START:
-selection = g_strdup_printf("Grace note: %s duration %d ", ((grace *) curObj->object)->on_beat?"On beat":"Before beat",
-			     ((grace *) curObj->object)->duration);
-break;
-  case GRACE_END:
-selection = g_strdup_printf("Grace note end");
-break;
-  case LYRIC:
-selection = g_strdup_printf("Lyric: %s",  ((lyric *) curObj->object)->lyrics->str  );
-break;
-  case FIGURE:
-selection = g_strdup_printf("Figure");
-break;
-
-    case LILYDIRECTIVE:
-      selection = g_strdup_printf("Lily directive: %s", ((GString *)((lilydirective *) curObj->object)->directive)->str);
-      break;
-  case FAKECHORD:
-selection = g_strdup_printf("Fakechord"   );
-break;
-  case PARTIAL:
-selection = g_strdup_printf("Partial"   );
-break;
-    default:
-      selection = g_strdup_printf("Unlisted object selected");
-    }
-  } else
-    selection = g_strdup_printf("No selection");
-  gtk_statusbar_pop(GTK_STATUSBAR (gui->statusbar), gui->status_context_id);
-  gtk_statusbar_push(GTK_STATUSBAR (gui->statusbar), gui->status_context_id,
-		     selection);
-  g_free(selection);
-
-  	  gtk_widget_queue_draw (gui->scorearea);
+      if(gui->si->markstaffnum)
+	unset_mark(gui);
+      else
+	set_mark(gui);
+      write_status(gui);
+      /* Redraw to reset si->cursorclef.  FIXME the design, or lack of it*/
+      gtk_widget_queue_draw (gui->scorearea);     
   }
   return TRUE;
 }
