@@ -900,7 +900,7 @@ static void create_pitch_recognition_window(DenemoGUI *gui) {
   PR_continuous = FALSE;
   g_signal_connect (G_OBJECT (button), "clicked",
 		    G_CALLBACK (toggle_continuous), gui);
-  gtk_toggle_button_set_active(button, TRUE);
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
 
   label = gtk_label_new("Click Volume");
   gtk_box_pack_start (GTK_BOX (hbox2), label, TRUE, TRUE, 0);
