@@ -76,10 +76,10 @@ toggle_plugin (GtkCellRendererToggle * cell, gchar * path_str, gpointer data)
   gtk_tree_model_get (GTK_TREE_MODEL (model), &iter, COLUMN_LOADED, &enabled,
 		      -1);
 
-  g_print ("Path str %s \n", path_str);
+  //g_print ("Path str %s \n", path_str);
   gtk_tree_model_get (GTK_TREE_MODEL (model), &iter, COLUMN_PLUGIN, &plugin,
 		      -1);
-  g_print ("plugin %s\n", plugin);
+  //g_print ("plugin %s\n", plugin);
   enabled ^= 1;
   if (enabled)
     {
@@ -140,7 +140,7 @@ set_preferences (struct callbackdata *cbdata)
   prefs->saveparts =
   	gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON
   				  (cbdata->checkautosaveparts));
-  g_print ("Timeout %d \n", prefs->autosave_timeout);
+  //g_print ("Timeout %d \n", prefs->autosave_timeout);
 
   /* Now write it all to denemorc */
   writeXMLPrefs (prefs);
@@ -210,7 +210,7 @@ preferences_change (GtkAction * action, DenemoGUI * gui)
     gtk_check_button_new_with_label (_
 				     ("Play back entered notes immediately"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkimmediateplayback),
-				gui->prefs->immediateplayback);
+				Denemo.prefs.immediateplayback);
   gtk_table_attach (GTK_TABLE (table), checkimmediateplayback, 0, 2, 0, 1,
 		    (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0,
 		    0);
@@ -220,7 +220,7 @@ preferences_change (GtkAction * action, DenemoGUI * gui)
   /* Comment that out when the feature is added */
   gtk_widget_set_sensitive (checklilystyle, FALSE);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checklilystyle),
-				gui->prefs->lilyentrystyle);
+				Denemo.prefs.lilyentrystyle);
   gtk_table_attach (GTK_TABLE (table), checklilystyle, 0, 2, 1, 2,
 		    (GtkAttachOptions) (GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
@@ -229,7 +229,7 @@ preferences_change (GtkAction * action, DenemoGUI * gui)
     gtk_check_button_new_with_label (_("Clone chords when tying them"));
   gtk_widget_set_sensitive (checkclone, FALSE);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkclone),
-				gui->prefs->createclones);
+				Denemo.prefs.createclones);
   gtk_table_attach (GTK_TABLE (table), checkclone, 0, 2, 2, 3,
 		    (GtkAttachOptions) (GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
@@ -238,7 +238,7 @@ preferences_change (GtkAction * action, DenemoGUI * gui)
     gtk_check_button_new_with_label (_("Display durations toolbar"));
   gtk_widget_set_sensitive (checknotationpalette, TRUE);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checknotationpalette),
-				gui->prefs->notation_palette);
+				Denemo.prefs.notation_palette);
   gtk_table_attach (GTK_TABLE (table), checknotationpalette, 0, 2, 4, 5,
 		    (GtkAttachOptions) (GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
@@ -247,7 +247,7 @@ preferences_change (GtkAction * action, DenemoGUI * gui)
     gtk_check_button_new_with_label (_("Display articulation palette"));
   gtk_widget_set_sensitive (checkarticulationpalette, TRUE);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkarticulationpalette),
-				gui->prefs->articulation_palette);
+				Denemo.prefs.articulation_palette);
   gtk_table_attach (GTK_TABLE (table), checkarticulationpalette, 0, 2, 6, 7,
 		    (GtkAttachOptions) (GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
@@ -257,7 +257,7 @@ preferences_change (GtkAction * action, DenemoGUI * gui)
     gtk_check_button_new_with_label (_("Display rhythm pattern toolbar"));
   gtk_widget_set_sensitive (checkrhythmpalette, TRUE);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkrhythmpalette),
-				gui->prefs->rhythm_palette);
+				Denemo.prefs.rhythm_palette);
   gtk_table_attach (GTK_TABLE (table), checkrhythmpalette, 0, 2, 8, 9,
 		    (GtkAttachOptions) (GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
@@ -273,13 +273,13 @@ preferences_change (GtkAction * action, DenemoGUI * gui)
 
   checkautosave = gtk_check_button_new_with_label (_("Autosave every"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkautosave),
-				gui->prefs->autosave);
+				Denemo.prefs.autosave);
   gtk_box_pack_start (GTK_BOX (hbox), checkautosave, FALSE, FALSE, 0);
 
   autosaveentry = gtk_spin_button_new_with_range (1, 50, 1.0);
   gtk_spin_button_set_value (GTK_SPIN_BUTTON (autosaveentry),
-			     gui->prefs->autosave_timeout);
-  gtk_widget_set_sensitive (autosaveentry, gui->prefs->autosave);
+			     Denemo.prefs.autosave_timeout);
+  gtk_widget_set_sensitive (autosaveentry, Denemo.prefs.autosave);
   gtk_box_pack_start (GTK_BOX (hbox), autosaveentry, FALSE, FALSE, 0);
 
   label = gtk_label_new (_("minute(s)"));
@@ -291,7 +291,7 @@ preferences_change (GtkAction * action, DenemoGUI * gui)
   checkautosaveparts = gtk_check_button_new_with_label(_("Autosave Parts"));
   gtk_widget_set_sensitive (checkarticulationpalette, FALSE);
    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkautosaveparts),
-				gui->prefs->saveparts);
+				Denemo.prefs.saveparts);
   gtk_table_attach(GTK_TABLE(table), checkautosaveparts, 0,2, 11,12,
   				   (GtkAttachOptions) (GTK_FILL),
   				   (GtkAttachOptions) (0), 0,0);
@@ -314,7 +314,7 @@ preferences_change (GtkAction * action, DenemoGUI * gui)
 		    (GtkAttachOptions) (0), 0, 0);
 
   lilypathentry = gtk_entry_new ();
-  gtk_entry_set_text (GTK_ENTRY (lilypathentry), gui->prefs->lilypath->str);
+  gtk_entry_set_text (GTK_ENTRY (lilypathentry), Denemo.prefs.lilypath->str);
   gtk_table_attach (GTK_TABLE (table), lilypathentry, 1, 2, 0, 1,
 		    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
@@ -325,7 +325,7 @@ preferences_change (GtkAction * action, DenemoGUI * gui)
 		    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
   pdfviewer = gtk_entry_new ();
-  gtk_entry_set_text (GTK_ENTRY (pdfviewer), gui->prefs->pdfviewer->str);
+  gtk_entry_set_text (GTK_ENTRY (pdfviewer), Denemo.prefs.pdfviewer->str);
   gtk_table_attach (GTK_TABLE (table), pdfviewer, 1, 2, 1, 2,
 		    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
@@ -336,7 +336,7 @@ preferences_change (GtkAction * action, DenemoGUI * gui)
 		    (GtkAttachOptions) (0), 0, 0);
 
   texteditor = gtk_entry_new ();
-  gtk_entry_set_text (GTK_ENTRY (texteditor), gui->prefs->texteditor->str);
+  gtk_entry_set_text (GTK_ENTRY (texteditor), Denemo.prefs.texteditor->str);
   gtk_table_attach (GTK_TABLE (table), texteditor, 1, 2, 2, 3,
 		    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
@@ -348,8 +348,8 @@ preferences_change (GtkAction * action, DenemoGUI * gui)
 		    (GtkAttachOptions) (0), 0, 0);
 
   denemopath = gtk_entry_new ();
-  if (gui->prefs->denemopath != NULL)
-  	gtk_entry_set_text (GTK_ENTRY (denemopath), gui->prefs->denemopath->str);
+  if (Denemo.prefs.denemopath != NULL)
+  	gtk_entry_set_text (GTK_ENTRY (denemopath), Denemo.prefs.denemopath->str);
   gtk_table_attach (GTK_TABLE (table), denemopath, 1, 2, 3, 4,
 		    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
@@ -386,7 +386,7 @@ preferences_change (GtkAction * action, DenemoGUI * gui)
   if (plugins)
     {
       GList *tmp;
-      g_print ("list of plugins is populated\n");
+      //g_print ("list of plugins is populated\n");
       for (tmp = plugins; tmp; tmp = tmp->next)
 	{
 	  gtk_list_store_append (list_store, &iter);
@@ -444,7 +444,7 @@ preferences_change (GtkAction * action, DenemoGUI * gui)
 		    (GtkAttachOptions) (GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
   browserentry = gtk_entry_new ();
-  gtk_entry_set_text (GTK_ENTRY (browserentry), gui->prefs->browser->str);
+  gtk_entry_set_text (GTK_ENTRY (browserentry), Denemo.prefs.browser->str);
   gtk_table_attach (GTK_TABLE (table), browserentry, 1, 2, 0, 1,
 		    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
@@ -452,7 +452,7 @@ preferences_change (GtkAction * action, DenemoGUI * gui)
 
 
   /* Set up the callback data */
-  cbdata.prefs = gui->prefs;
+  cbdata.prefs = &Denemo.prefs;
   cbdata.lilypathentry = lilypathentry;
   cbdata.checkimmediateplayback = checkimmediateplayback;
   cbdata.checklilystyle = checklilystyle;
@@ -492,7 +492,7 @@ get_plugins_list (GList * plugins)
   struct dirent *dirent;
   char *name;
   //dirname = g_strconcat(dirname, "/denemo/", NULL);
-  g_print ("Directory %s\n", get_plugin_dir ());
+  //g_print ("Directory %s\n", get_plugin_dir ());
   dir = opendir (get_plugin_dir ());
 
   if (!dir)
@@ -500,7 +500,7 @@ get_plugins_list (GList * plugins)
 
   while ((dirent = readdir (dir)) != NULL)
     {
-      g_print ("Filename is %s\n", dirent->d_name);
+      //g_print ("Filename is %s\n", dirent->d_name);
       if ((name = stripname (dirent->d_name)) != NULL)
 	plugins = g_list_append (plugins, name);
     }
