@@ -61,11 +61,11 @@ locatedotdenemo ()
  * then local preferences file
  *
  */
-DenemoPrefs *
+void
 initprefs ()
 {
   gchar *systemwide = g_build_filename (get_data_dir (), "denemo.conf", NULL);
-  DenemoPrefs *ret = (DenemoPrefs *) g_malloc (sizeof (DenemoPrefs));
+  DenemoPrefs *ret = &Denemo.prefs;
   gchar * dotdenemo = locatedotdenemo ();
   gchar *localrc = dotdenemo?g_build_filename (dotdenemo, "denemorc", NULL):NULL;
 
@@ -80,7 +80,7 @@ initprefs ()
   ret->pdfviewer = g_string_new ("xpdf");
   ret->texteditor = g_string_new ("xedit");
   ret->denemopath = g_string_new (g_get_home_dir());
-  ret->lilyversion = g_string_new ("");
+  ret->lilyversion = g_string_new (LILYPOND_VERSION);
   ret->immediateplayback = TRUE;
   ret->saveparts = FALSE;
   ret->rtcs = TRUE;
@@ -109,7 +109,6 @@ initprefs ()
   }
   g_free (systemwide);
   g_free (localrc);
-  return ret;
 }
 
 
@@ -181,6 +180,7 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
 	  if(tmp)
 	    {
 	      prefs->autosave_timeout = atoi ((gchar *) tmp);
+	      if(prefs->autosave_timeout <1) prefs->autosave_timeout = 1;
 	      g_print ("Autosave Timeout %s\n", tmp);
 	      xmlFree (tmp);
 	    }
@@ -396,7 +396,7 @@ parseHistory (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
 	      g_print ("Filename %s\n", tmp);
 #endif
 
-	      g_queue_push_tail (prefs->history, file);
+	      g_queue_push_tail (prefs->history, g_strdup(file));
 	      g_free (tmp);
 	    }
 	}
@@ -568,7 +568,7 @@ writeXMLPrefs (DenemoPrefs * prefs)
  *
  */
 gint
-readHistory (DenemoPrefs * prefs)
+readHistory ()
 {
   gint ret = -1;
   xmlDocPtr doc = NULL;
@@ -613,7 +613,7 @@ readHistory (DenemoPrefs * prefs)
 #endif
       if (0 == xmlStrcmp (rootElem->name, (const xmlChar *) "History"))
 	{
-	  parseHistory (doc, rootElem, prefs);
+	  parseHistory (doc, rootElem, &Denemo.prefs);
 	}
 
       rootElem = rootElem->next;
@@ -630,11 +630,11 @@ readHistory (DenemoPrefs * prefs)
 /**
  * Write denemohistory file
  *
- * @param prefs	pointer to the preferences structure 
+ * @param none
  *
  */
 void
-writeHistory (DenemoPrefs * prefs)
+writeHistory (void)
 {
 
 
@@ -651,8 +651,83 @@ writeHistory (DenemoPrefs * prefs)
   doc->xmlRootNode = parent =
     xmlNewDocNode (doc, NULL, (xmlChar *) "Denemo", NULL);
   child = xmlNewChild (parent, NULL, (xmlChar *) "History", NULL);
-  g_queue_foreach (prefs->history, writeHistoryEntry, child);
+  g_queue_foreach (Denemo.prefs.history, writeHistoryEntry, child);
   xmlSaveFormatFile (filename->str, doc, 0);
   xmlFreeDoc (doc);
 
 }
+
+/**
+ * Store default window position
+ *
+ * @param the denemo gui
+ *
+ */
+void storeWindowState (DenemoGUI *gui)
+{
+   GKeyFile *keyfile;
+   gchar *contents;
+   gchar *filename;
+
+   gtk_window_get_size (gui->window, &(gui->width), &(gui->height));
+   keyfile = g_key_file_new ();
+   g_key_file_set_integer (keyfile, "State", "width", gui->width);
+   g_key_file_set_integer (keyfile, "State", "height", gui->height);
+   g_key_file_set_boolean (keyfile, "State", "maximized", gui->maximized);
+   contents = g_key_file_to_data (keyfile, NULL, NULL);
+   g_key_file_free (keyfile);
+   filename = g_build_filename (locatedotdenemo (), "state.ini", NULL);
+   g_file_set_contents (filename, contents, -1, NULL);
+   g_free (filename);
+   g_free (contents); 
+}
+
+/**
+ * Load default window position
+ *
+ * @param the denemo gui
+ *
+ */
+void loadWindowState (DenemoGUI *gui)
+{
+    gchar *filename;
+    GKeyFile *keyfile;
+    gint w,h;
+    gboolean maximized;
+    GError *err=NULL;
+
+    filename = g_build_filename (locatedotdenemo (), "state.ini", NULL);
+    keyfile = g_key_file_new ();
+    if (g_key_file_load_from_file (keyfile, filename, G_KEY_FILE_NONE, NULL) == FALSE) {
+        g_free (filename);
+        w = INITIAL_WIDTH;
+        h = INITIAL_HEIGHT;
+    } else {
+        g_free (filename);
+        w = g_key_file_get_integer (keyfile, "State", "width", &err);
+        if (err != NULL) {
+            w = 0;
+            g_error_free (err);
+            err = NULL;
+        }
+        h = g_key_file_get_integer (keyfile, "State", "height", &err);
+        if (err != NULL) {
+            h = 0;
+            g_error_free (err);
+            err = NULL;
+        }
+        maximized = g_key_file_get_boolean (keyfile, "State", "maximized", &err);
+        if (err != NULL) {
+            g_error_free (err);
+            err = NULL;
+        }
+        g_key_file_free (keyfile);
+        if (w > 0 && h > 0 && maximized == FALSE) {
+                gtk_window_set_default_size (GTK_WINDOW (gui->window), w, h);
+                gui->width = w;
+                gui->height = h;
+        } else if (gui->maximized != FALSE) {
+                gtk_window_maximize (GTK_WINDOW (gui->window));
+        }
+    }
+}
