@@ -10,12 +10,15 @@
 #include <denemo/denemo.h>
 #include "plugin.h"
 
+#define INITIAL_WIDTH 1000
+#define INITIAL_HEIGHT 500
+
 const gchar *locatedotdenemo ();
 
-DenemoPrefs *initprefs ();
+void initprefs (void);
 GList* get_plugins_list(GList *plugins);
 gint writeXMLPrefs( DenemoPrefs *prefs);
-void writeHistory(DenemoPrefs *prefs);
-gint readHistory(DenemoPrefs *prefs);
+void writeHistory(void);
+gint readHistory(void);
 
 #endif
