@@ -34,19 +34,31 @@
  *  TODO Add in lpr command
  */
 static void
-print (DenemoGUI * gui, gboolean part_only)
+print (DenemoGUI * gui, gboolean part_only, gboolean all_movements)
 {
-  static GString *filename = NULL;
+  static gchar *filename = NULL;
   GError *err = NULL;
   DenemoScore *si = gui->si;
 
-  if (!filename)
-    {
-      filename = g_string_new (locatedotdenemo ());
-      g_string_append (filename, "/denemoprint");
-    }
 
-  gchar *printfile = g_strconcat (filename->str, ".pdf", NULL);
+
+#ifdef G_OS_WIN32
+ {
+   static int count=1;
+   gchar *denemoprint = g_strdup_printf("denemoprint%d", count);
+   count++;
+   if(filename)
+     g_free(filename);
+   filename = g_build_filename ( locatedotdenemo (), denemoprint, NULL);
+   g_free(denemoprint);
+ }
+#else
+  if (!filename)
+      filename = g_build_filename ( locatedotdenemo (), "denemoprint", NULL);
+#endif
+  gchar *printfile = g_strconcat (filename, ".pdf", NULL);
+
+
   FILE *fp = fopen(printfile, "w");
   if(fp)
     fclose(fp);
@@ -55,13 +67,20 @@ print (DenemoGUI * gui, gboolean part_only)
     return;
   }
 
-  gchar *mudelafile = g_strconcat (filename->str, ".ly", NULL);
+  gchar *mudelafile = g_strconcat (filename, ".ly", NULL);
   remove (mudelafile);
   if(part_only)
-    export_lilypond_part (mudelafile, si, si->start, si->end);
+    export_lilypond_part (mudelafile, gui, si->start, si->end, all_movements);
   else
-    exportlilypond (mudelafile, si, 0, 0);
+    exportlilypond (mudelafile, gui, 0, 0, all_movements);
+
+#ifdef G_OS_WIN32
+/*   gchar *dirname = g_path_get_dirname (Denemo.prefs.lilypath->str ); */
+/*   gchar *convert = g_build_filename(dirname, "convert-ly.py");// FIXME memory leaks */
+
+#else
   gchar *convert = "convert-ly";
+
   gchar *conv_argv[] = {
     convert,
     "-e",
@@ -69,27 +88,34 @@ print (DenemoGUI * gui, gboolean part_only)
     NULL
   };
 
-  gint exit_status;
+/* (denemo:29198): GLib-WARNING **: In call to g_spawn_sync(), exit status of a child process was requested but SIGCHLD action was set to SIG_IGN and ECHILD was received by waitpid(), so exit status can't be returned. This is a bug in the program calling g_spawn_sync(); either don't request the exit status, or don't set the SIGCHLD action. 
+ FIXED*/
+
   g_spawn_sync (locatedotdenemo (),		/* dir */
 		conv_argv, NULL,	/* env */
 		G_SPAWN_SEARCH_PATH, NULL,	/* child setup func */
 		NULL,		/* user data */
 		NULL,		/* stdout */
 		NULL,		/* stderr */
-		&exit_status, &err);
+		NULL, &err);
 
   if (err != NULL)
     {
-      warningdialog("Could not execute lilypond's convert-ly program - check Edit->preferences->externals->lilypond setting\nand lilypond installation");
+      warningdialog("Could not execute lilypond's convert-ly program - check lilypond installation or just ignore");
       g_warning ("%s", err->message);
       g_error_free (err);
       err = NULL;
     }
+#endif
+
+
+
+
   gchar *argv[] = {
-    gui->prefs->lilypath->str,
+    Denemo.prefs.lilypath->str,
     "--pdf",
     "-o",
-    filename->str,
+    filename,
     mudelafile,
     NULL
   };
@@ -100,14 +126,14 @@ print (DenemoGUI * gui, gboolean part_only)
 		NULL,		/* user data */
 		NULL,		/* stdout */
 		NULL,		/* stderr */
-		&exit_status, &err);
+		NULL, &err);
 
   if (err != NULL)
     {
       warningdialog("Could not execute lilypond - check Edit->preferences->externals->lilypond setting\nand lilypond installation");
       g_warning ("%s", err->message);
       g_error_free (err);
-      err = NULL; 
+      err = NULL;
     }
 
 
@@ -125,28 +151,25 @@ print (DenemoGUI * gui, gboolean part_only)
   }
     
 
-
   //g_print("using %s\n", printfile);
   gchar *args[] = {
-    gui->prefs->pdfviewer->str,
+    Denemo.prefs.pdfviewer->str,
     printfile,
     NULL
   };
 
- 
-  exit_status = 0;
-
   GPid printpid;//ignored
   g_spawn_async (locatedotdenemo (),		/* dir */
-		args, NULL,	/* env */
-		G_SPAWN_SEARCH_PATH, NULL,	/* child setup func */
-		NULL,		/* user data */		
-		&printpid, &err);
-
+		 args, NULL,	/* env */
+		 G_SPAWN_SEARCH_PATH, /* search in path for executable */
+		 NULL,	/* child setup func */
+		 NULL,		/* user data */		
+		 NULL, &err);
+  
 
   if (err != NULL)
     {
-      g_warning ("Failed to find %s", gui->prefs->pdfviewer->str);
+      g_warning ("Failed to find %s", Denemo.prefs.pdfviewer->str);
       warningdialog("Cannot display: Check Edit->Preferences->externals\nfor your PDF viewer");
       g_warning ("%s", err->message);
       g_error_free (err);
@@ -161,17 +184,22 @@ print (DenemoGUI * gui, gboolean part_only)
 /* callback to print whole of score */
 void
 printall_cb (GtkAction * action, DenemoGUI * gui) {
-  gchar *str = g_strdup_printf("No direct printing yet\nWe will run the PDF viewer program %s so you can use its print command.\nYou can change the PDF viewer using \nEdit->Preferences->Externals->Pdf viewer.", gui->prefs->pdfviewer->str);
+  gchar *str = g_strdup_printf("No direct printing yet\nWe will run the PDF viewer program %s so you can use its print command.\nYou can change the PDF viewer using \nEdit->Preferences->Externals->Pdf viewer.", Denemo.prefs.pdfviewer->str);
   warningdialog(str);
   g_free(str);
-  print(gui, FALSE);
+  print(gui, FALSE, TRUE);
 }
 /* callback to print current part (staff) of score */
 void
 printpart_cb (GtkAction * action, DenemoGUI * gui) {
-  print(gui, TRUE);
+  if((gui->movements && g_list_length(gui->movements)>1) && 
+     (confirm("This piece has several movements", "Print this part from all of them?")))
+    print(gui, TRUE, TRUE);
+  else
+   print(gui, TRUE, FALSE);
+  
 }
 void
 printpreview_cb (GtkAction * action, DenemoGUI * gui) {
-  print(gui, FALSE);
+  print(gui, FALSE, TRUE);
 }
