@@ -66,131 +66,11 @@ score_properties_dialog (GtkAction * action, DenemoGUI * gui)
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), notebook, TRUE,
 		      TRUE, 0);
 
-  // Headers
-  /* 
-  scrolled_window = gtk_scrolled_window_new (NULL, NULL);
-  gtk_container_set_border_width (GTK_CONTAINER (scrolled_window), 12);
-  gtk_widget_set_size_request (scrolled_window, 350, 300);
-  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
-				      GTK_POLICY_AUTOMATIC,
-				      GTK_POLICY_AUTOMATIC);
-  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW
-					   (scrolled_window), GTK_SHADOW_IN);
-
-  label = gtk_label_new_with_mnemonic (_("_Headers"));
-  gtk_notebook_append_page (GTK_NOTEBOOK (notebook), scrolled_window,
-				label);
-  */
-  //list_store = gtk_list_store_new (3, G_TYPE_STRING,	/* label */
-	//			      G_TYPE_STRING,	/* value */
-	//			      G_TYPE_POINTER);	/* pointer to the corresponding header field */
-  /*
-  list = gtk_tree_view_new_with_model (GTK_TREE_MODEL (list_store));
-  gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (list),
-						 0, "Name",
-						 gtk_cell_renderer_text_new
-						 (), "text", 0, NULL);
-  gtk_container_add (GTK_CONTAINER (scrolled_window), list);
-  renderer = gtk_cell_renderer_text_new ();
-  g_object_set (renderer, "editable", TRUE, NULL);
-  g_object_set (renderer, "width", 200, NULL);
-  g_signal_connect (renderer, "edited", (GCallback) cell_edited,
-			list_store);
-  gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (list), 1,
-						   "Value", renderer, "text",
-						   1, NULL);
-
-  gtk_list_store_append (list_store, &iter);
-  gtk_list_store_set (list_store, &iter,
-			  COL_NAME, _("Title"),
-			  COL_VALUE, si->headerinfo->title->str,
-			  COL_PTR, &(si->headerinfo->title->str), -1);
-
-  gtk_list_store_append (list_store, &iter);
-  gtk_list_store_set (list_store, &iter,
-			  COL_NAME, _("Subtitle"),
-			  COL_VALUE, si->headerinfo->subtitle->str,
-			  COL_PTR, &(si->headerinfo->subtitle->str), -1);
-
-  gtk_list_store_append (list_store, &iter);
-  gtk_list_store_set (list_store, &iter,
-			  COL_NAME, _("Poet"),
-			  COL_VALUE, si->headerinfo->poet->str,
-			  COL_PTR, &(si->headerinfo->poet->str), -1);
-
-  gtk_list_store_append (list_store, &iter);
-  gtk_list_store_set (list_store, &iter,
-			  COL_NAME, _("Composer"),
-			  COL_VALUE, si->headerinfo->composer->str,
-			  COL_PTR, &(si->headerinfo->composer->str), -1);
-
-  gtk_list_store_append (list_store, &iter);
-  gtk_list_store_set (list_store, &iter,
-			  COL_NAME, _("Meter"),
-			  COL_VALUE, si->headerinfo->meter->str,
-			  COL_PTR, &(si->headerinfo->meter->str), -1);
-
-  gtk_list_store_append (list_store, &iter);
-  gtk_list_store_set (list_store, &iter,
-			  COL_NAME, _("Opus"),
-			  COL_VALUE, si->headerinfo->opus->str,
-			  COL_PTR, &(si->headerinfo->opus->str), -1);
-
-  gtk_list_store_append (list_store, &iter);
-  gtk_list_store_set (list_store, &iter,
-			  COL_NAME, _("Arranger"),
-			  COL_VALUE, si->headerinfo->arranger->str,
-			  COL_PTR, &(si->headerinfo->arranger->str), -1);
-
-  gtk_list_store_append (list_store, &iter);
-  gtk_list_store_set (list_store, &iter,
-			  COL_NAME, _("Instrument"),
-			  COL_VALUE, si->headerinfo->instrument->str,
-			  COL_PTR, &(si->headerinfo->instrument->str), -1);
-
-  gtk_list_store_append (list_store, &iter);
-  gtk_list_store_set (list_store, &iter,
-			  COL_NAME, _("Dedication"),
-			  COL_VALUE, si->headerinfo->dedication->str,
-			  COL_PTR, &(si->headerinfo->dedication->str), -1);
-
-  gtk_list_store_append (list_store, &iter);
-  gtk_list_store_set (list_store, &iter,
-			  COL_NAME, _("Piece"),
-			  COL_VALUE, si->headerinfo->piece->str,
-			  COL_PTR, &(si->headerinfo->piece->str), -1);
-
-  gtk_list_store_append (list_store, &iter);
-  gtk_list_store_set (list_store, &iter,
-			  COL_NAME, _("Head"),
-			  COL_VALUE, si->headerinfo->head->str,
-			  COL_PTR, &(si->headerinfo->head->str), -1);
-
-  gtk_list_store_append (list_store, &iter);
-  gtk_list_store_set (list_store, &iter,
-			  COL_NAME, _("Copyright"),
-			  COL_VALUE, si->headerinfo->copyright->str,
-			  COL_PTR, &(si->headerinfo->copyright->str), -1);
-
-  gtk_list_store_append (list_store, &iter);
-  gtk_list_store_set (list_store, &iter,
-			  COL_NAME, _("Footer"),
-			  COL_VALUE, si->headerinfo->footer->str,
-			  COL_PTR, &(si->headerinfo->footer->str), -1);
-
-  gtk_list_store_append (list_store, &iter);
-  gtk_list_store_set (list_store, &iter,
-			  COL_NAME, _("Tagline"),
-			  COL_VALUE, si->headerinfo->tagline->str,
-			  COL_PTR, &(si->headerinfo->tagline->str), -1);
-
-  */
-  
+  // Headers  
   hsetup = headersetup (notebook, gui, TRUE);
 
   // Layout
   label = gtk_label_new_with_mnemonic (_("La_yout"));
-
   table = gtk_table_new (2, 2, FALSE);
   gtk_container_set_border_width (GTK_CONTAINER (table), 12);
   gtk_table_set_row_spacings (GTK_TABLE (table), 8);
@@ -233,7 +113,7 @@ score_properties_dialog (GtkAction * action, DenemoGUI * gui)
   if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
     {
       // Set headers
-      applyheader_settings(hsetup,si);
+      applyheader_settings(hsetup,gui);
 	/*
        if (!si->lily_file)
 	{
@@ -268,9 +148,150 @@ score_properties_dialog (GtkAction * action, DenemoGUI * gui)
 	  si->staffspace = spacing;
 	  gtk_widget_queue_draw (gui->scorearea);
 	}
-      setpaperconfig (cbdata, si);
+      setpaperconfig (cbdata, gui);
 
     }
   g_free (cbdata);
   gtk_widget_destroy (dialog);
 }
+
+
+
+
+
+/***************** movement properties *********************/
+struct callbackdata
+{
+  DenemoGUI *gui;
+
+  GtkWidget *title;	  
+  GtkWidget *subtitle;	  
+  GtkWidget *poet;	  
+  GtkWidget *composer;	  
+  GtkWidget *meter;	  
+  GtkWidget *opus; 	  
+  GtkWidget *arranger;	  
+  GtkWidget *instrument;	  
+  GtkWidget *dedication;	  
+  GtkWidget *piece;	  
+  GtkWidget *head;	  
+  GtkWidget *copyright;	  
+  GtkWidget *footer;	  
+  GtkWidget *tagline;	  
+
+  GtkWidget *markup_before; 
+  GtkWidget *markup_after;  
+  GtkWidget *extra;  
+};
+
+/**
+ * Function to set the properties
+ *
+ */
+static void
+set_movement_props (gpointer data)
+{
+  struct callbackdata *cbdata = (struct callbackdata *) data;
+  DenemoGUI *gui = cbdata->gui;
+  DenemoScore *si = gui->si;
+#define ASSIGN(field) g_string_assign(si->headerinfo.field , (gchar *) gtk_entry_get_text (GTK_ENTRY (cbdata->field)));
+ASSIGN(title);	  
+ASSIGN(subtitle);	  
+ASSIGN(poet);	  
+ASSIGN(composer);	  
+ASSIGN(meter);	  
+ASSIGN(opus);	  
+ASSIGN(arranger);	  
+ASSIGN(instrument);	  
+ASSIGN(dedication);	  
+ASSIGN(piece);	  
+ASSIGN(head);	  
+ASSIGN(copyright);	  
+ASSIGN(footer);	  
+ASSIGN(tagline);	  
+ASSIGN(markup_before); 
+ASSIGN(markup_after);  
+ASSIGN(extra); 
+}
+
+/**
+ * Creates a dialog for setting properties of current movement gui->si
+ *
+ */
+void
+movement_props_dialog (GtkAction * action, DenemoGUI * gui)
+{
+  GtkWidget *dialog;
+
+  GtkWidget *label;
+
+  DenemoScore *si = gui->si;
+  static struct callbackdata cbdata;
+  cbdata.gui = gui;
+  dialog = gtk_dialog_new_with_buttons (_("Edit Properties of Movement"),
+					GTK_WINDOW (gui->window),
+					(GtkDialogFlags) (GTK_DIALOG_MODAL |
+							  GTK_DIALOG_DESTROY_WITH_PARENT),
+					GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
+					GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
+					NULL);
+
+  gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
+
+
+GtkWidget *hpaned;
+GtkWidget *frame1;
+GtkWidget *frame2;
+  GtkWidget *entry;
+#define ACCESS(field) hpaned = gtk_hpaned_new ();\
+  frame1 = gtk_frame_new (NULL);\
+  frame2 = gtk_frame_new (NULL);\
+  gtk_frame_set_shadow_type (GTK_FRAME (frame1), GTK_SHADOW_IN);\
+  gtk_frame_set_shadow_type (GTK_FRAME (frame2), GTK_SHADOW_IN);\
+  gtk_paned_pack1 (GTK_PANED (hpaned), frame1, FALSE, FALSE);\
+  gtk_paned_pack2 (GTK_PANED (hpaned), frame2, TRUE, FALSE);\
+  gtk_widget_set_size_request (frame1, 100, -1);\
+  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hpaned, TRUE, TRUE, 0);\
+  label = gtk_label_new (_(#field));\
+  gtk_container_add (GTK_CONTAINER (frame1), label);\
+  entry = gtk_entry_new ();\
+  cbdata.field = entry;\
+  if (si->headerinfo.field)\
+	gtk_entry_set_text (GTK_ENTRY (entry), si->headerinfo.field->str);\
+  gtk_container_add (GTK_CONTAINER (frame2), entry);\
+  gtk_entry_set_activates_default (GTK_ENTRY (entry), TRUE);
+
+  ACCESS(title);	  
+  ACCESS(subtitle);	  
+  ACCESS(poet);	  
+  ACCESS(composer);	  
+  ACCESS(meter);	  
+  ACCESS(opus);	  
+  ACCESS(arranger);	  
+  ACCESS(instrument);	  
+  ACCESS(dedication);	  
+  ACCESS(piece);	  
+  ACCESS(head);	  
+  ACCESS(copyright);	  
+  ACCESS(footer);	  
+  ACCESS(tagline);	  
+
+  ACCESS(markup_before); 
+  ACCESS(markup_after);  
+  ACCESS(extra);  
+
+
+
+
+
+  /* gtk_widget_grab_focus (name); */
+  gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
+  gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_MOUSE);
+  gtk_widget_show_all (dialog);
+
+  if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
+    {
+      set_movement_props (&cbdata);
+    }
+  gtk_widget_destroy (dialog);
+}
