@@ -154,14 +154,14 @@ insert_staff (DenemoScore * si, DenemoStaff * thestaffstruct,
 	      enum newstaffcallbackaction action, gint addat)
 {
   si->thescore = g_list_insert (si->thescore, thestaffstruct, addat - 1);
-  if (action == BEFORE)
-    si->currentstaff = g_list_nth (si->thescore, addat - 1);
-  else
-    si->currentstaff = g_list_nth (si->thescore, si->currentstaffnum - 1);
-  setcurrentprimarystaff (si);
-  find_leftmost_staffcontext (thestaffstruct, si);
-  g_print ("newstaff: Num staffs after insert %d\n",
-	   g_list_length (si->thescore));
+  if (action != BEFORE)
+    if (action != AFTER) {
+      si->currentstaff = g_list_nth (si->thescore, addat - 1);
+      si->currentstaffnum = addat;
+      setcurrentprimarystaff (si);
+      find_leftmost_staffcontext (thestaffstruct, si);
+    }
+
 
 }
 
@@ -211,23 +211,25 @@ newstaff (DenemoScore * si, enum newstaffcallbackaction action,
       thestaffstruct->volume = 128;
       thestaffstruct->nummeasures = 1;
 
+#if 0
       si->measurewidths = g_list_append (si->measurewidths,
 					 GINT_TO_POINTER (si->measurewidth));
+#else
+      si->measurewidths = g_list_append (NULL,  GINT_TO_POINTER (si->measurewidth));//FIXME free old measurewidths
+#endif
     }
-  else
-    {
-      /* how did this work before? a new staff must have the same number of
-	 measures as the present one(s) */
+  else {
+      /* how did this work before? a new staff must have the same number of measures as the present one(s) */
       thestaffstruct->nummeasures = g_list_length (firstmeasurenode (si->thescore));
       copy_staff_bits ((DenemoStaff *) si->currentstaff->data,
 		       thestaffstruct);
-    };
+    }
 
   if (action == NEWVOICE)
     {
       thestaffstruct->voicenumber = 2;
       thestaffstruct->nummeasures =
-	g_list_length (firstmeasurenode (si->currentstaff));
+	g_list_length (firstmeasurenode (si->currentstaff));//FIXME redundant
     }
   else if (action == LYRICSTAFF)
     {
@@ -254,7 +256,15 @@ newstaff (DenemoScore * si, enum newstaffcallbackaction action,
   if (action == INITIAL || action == ADDFROMLOAD)
     {
       si->currentmeasure = themeasures;
-    };
+    }
+
+#if 0
+  // always go home for new staffs.
+ else {
+      si->currentmeasure = g_list_nth(themeasures, si->currentmeasurenum - 1);
+
+    }
+#endif
 
   /* Now fix the stuff that shouldn't be directly copied from
    * the current staff, if this staff was non-initial and that
@@ -343,7 +353,7 @@ newstaff (DenemoScore * si, enum newstaffcallbackaction action,
 	    }
 	}
     }
-  else
+  else // is INITIAL or ADDFROMLOAD
     {
       insert_staff (si, thestaffstruct, action, addat);
     }
@@ -352,68 +362,43 @@ newstaff (DenemoScore * si, enum newstaffcallbackaction action,
 }
 
 /**
- * Remove a number = 1 of staffs from the score
+ * Remove the si->currentstaff from the score si and resets si->currentstaff
  * @param si the scoreinfo structure
- * @param pos the position of the staff to remove, starting a 0
- * @param unused numstaffs the number of staffs to remove
- * @return none
+
+ * @return TRUE if a staff was deleted
  */
-void
-removestaff (DenemoScore * si, gint pos, gint numstaffs)
+gboolean
+deletestaff (DenemoScore * si)
 {
-  /* The second and third parameters are mostly ignored in this version
-   * of the function */
-  DenemoStaff *curstaffstruct = (DenemoStaff *) (si->currentstaff ?
-						 si->currentstaff->
-						 data : NULL);
-  if (curstaffstruct)
+  gboolean ret=FALSE;
+  if(si->currentstaff==NULL)
+    return ret;
+  DenemoStaff *curstaffstruct = si->currentstaff->data;
+  gboolean isprimary = ((int) curstaffstruct->voicenumber == 1);
+  //FIXME free_staff()
+  g_list_foreach (curstaffstruct->measures, freeobjlist, NULL);
+  g_list_free (curstaffstruct->measures);
+  g_string_free (curstaffstruct->denemo_name, FALSE);
+  g_string_free (curstaffstruct->lily_name, FALSE);
+  g_string_free (curstaffstruct->midi_instrument, FALSE);
+  g_free (curstaffstruct);
+  if(si->currentstaff==g_list_last(si->thescore))
+    si->currentstaffnum--;//deleting the last, so the currentstaffnum must decrease
+  si->thescore = g_list_delete_link (si->thescore, si->currentstaff);
+  if(si->thescore==NULL) {
+    ret = FALSE;
+    newstaff (si, INITIAL, DENEMO_NONE);
+  }
+  si->currentstaff = g_list_nth (si->thescore, si->currentstaffnum - 1);
+  if (isprimary) // we deleted the primary, so the next one must become the primary
     {
-      if(g_list_length(si->thescore) < 2 || pos > g_list_length(si->thescore)-1 || pos < 0) /* FIXME do not let these happen - e.g. make DeleteStaffAfter button inactive when on last staff etc */
-	return; 
-      gboolean isprimary = ((int) curstaffstruct->voicenumber == 1) ?
-	TRUE : FALSE;
-      if (si->lily_file != NULL)
-	/* if a lily file, then the objects are freed
-	   with the lily tree */
-	g_list_foreach (curstaffstruct->measures, freeobjlist, NULL);
-      g_list_free (curstaffstruct->measures);
-      g_string_free (curstaffstruct->denemo_name, FALSE);
-      g_string_free (curstaffstruct->lily_name, FALSE);
-      g_string_free (curstaffstruct->midi_instrument, FALSE);
-      if (si->lily_file)
-	{
-	  curstaffstruct->measures = NULL;
-	  /* don't free the structure as a lily file references it */
-	}
-      else
-	g_free (curstaffstruct);
-      si->thescore = g_list_remove_link (si->thescore, si->currentstaff);
-      g_list_free_1 (si->currentstaff);
-      if (pos < si->currentstaffnum)
-	{
-	  if(si->currentstaffnum>1)
-	    si->currentstaffnum--;
-	};
-      si->currentstaff = g_list_nth (si->thescore, si->currentstaffnum - 1);
-      if (si->currentstaff)
-	{
-	  /* O.K.; set si->currentprimarystaff correctly */
-	  if (isprimary)
-	    {
-	      ((DenemoStaff *) si->currentstaff->data)->voicenumber = 1;
-	      si->currentprimarystaff = si->currentstaff;
-	    }
-	  else
-	    {
-	      setcurrentprimarystaff (si);
-	    };
-	}
-      else
-	{
-	  si->currentprimarystaff = NULL;
-	}
+      ((DenemoStaff *) si->currentstaff->data)->voicenumber = 1;
+      si->currentprimarystaff = si->currentstaff;
+    } else {
+      setcurrentprimarystaff (si);
     }
-}
+  return ret;
+}	
 
 /**
  * Sets the beams and stem directions across the given staff
@@ -512,9 +497,9 @@ fixnoteheights (DenemoStaff * thestaff)
 void
 newstaffinitial (GtkAction * action, DenemoGUI * gui)
 {
-  newstaff (gui->si, INITIAL, DENEMO_NONE);
-  set_bottom_staff (gui);
-  displayhelper (gui);
+  while(gui->si->currentstaff && gui->si->currentstaff->prev)
+    staffup(gui);
+  newstaffbefore (action, gui);
 }
 
 /**
@@ -527,9 +512,15 @@ void
 newstaffbefore (GtkAction * action, DenemoGUI * gui)
 {
   //  g_print ("New Staff before: score info %X\n", data);
+  tohome(NULL, gui);
   newstaff (gui->si, BEFORE, DENEMO_NONE);
+  if(gui->si->currentstaffnum>= gui->si->top_staff)
+    gui->si->top_staff++;
+  gui->si->currentstaffnum++;
+  gui->si->bottom_staff++;
   set_bottom_staff (gui);
   move_viewport_down (gui);
+
   staffup (gui);
   displayhelper (gui);
 
@@ -544,6 +535,7 @@ newstaffbefore (GtkAction * action, DenemoGUI * gui)
 void
 dnm_newstaffafter (GtkAction * action, DenemoGUI * gui)
 {
+  tohome(NULL, gui);
   newstaff (gui->si, AFTER, DENEMO_NONE);
   set_bottom_staff (gui);
   update_vscrollbar (gui);
@@ -560,11 +552,9 @@ dnm_newstaffafter (GtkAction * action, DenemoGUI * gui)
 void
 newstafflast (GtkAction * action, DenemoGUI * gui)
 {
-  newstaff (gui->si, LAST, DENEMO_NONE);
-  set_bottom_staff (gui);
-  update_vscrollbar (gui);
-  staffdown (gui);
-  displayhelper (gui);
+  while(gui->si->currentstaff && gui->si->currentstaff->next)
+    staffdown(gui);
+  dnm_newstaffafter(action, gui);
 }
 
 /**
@@ -579,7 +569,7 @@ dnm_newstaffvoice (GtkAction * action, DenemoGUI * gui)
   newstaff (gui->si, NEWVOICE, DENEMO_NONE);
   set_bottom_staff (gui);
   update_vscrollbar (gui);
-  staffdown (gui);
+  setcurrents(gui->si);//staffdown (gui);
   displayhelper (gui);
 }
 
