@@ -359,32 +359,8 @@ freeit (gpointer data, gpointer user_data)
   g_free (data);
 }
 
-/**
- * Displays a progress dialog 
- * 
- * @param gui pointer to the DenemoGUI structure
- * 
- */
-GtkWidget *
-progressdialog (DenemoGUI * gui)
-{
-  GtkWidget *dialog;
 
 
-  dialog = gtk_dialog_new ();
-  //vbox = gtk_vbox_new(FALSE,5);
-  //gtk_container_add(GTK_CONTAINER(dialog), vbox);
-
-  gui->progressbar = gtk_progress_bar_new ();
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), gui->progressbar,
-		      FALSE, FALSE, 5);
-
-  gtk_widget_show (gui->progressbar);
-  gtk_widget_show (dialog);
-
-  return (dialog);
-}
-
 
 
 
@@ -615,3 +591,49 @@ kill_process (GPid pid)
 gchar * music_font(gchar *str) {
   return g_strdup_printf("<span font_desc=\"Denemo 12\">%s</span>", str);
 }
+
+void  set_title_bar(DenemoGUI *gui) {
+  gchar *title;
+  if(gui->filename && gui->filename->len)
+    title = gui->filename->str;
+  else
+    title = "(Untitled)";
+  title = g_strdup_printf("Denemo - %s%c", title, gui->haschanged?'*':' ');   
+  gtk_window_set_title (GTK_WINDOW (gui->window), title);
+  g_free(title);
+}
+
+void score_status(DenemoGUI *gui, gboolean haschanged) {
+  if(gui->haschanged != haschanged) {
+    gui->haschanged = haschanged;
+    set_title_bar(gui);
+  }
+  write_status(gui);
+}
+
+
+/**
+ * Display a message box asking primary & secondary messages
+ * @return TRUE if the OK button was clicked or Enter pressed
+ */
+gboolean
+confirm (gchar *primary, gchar *secondary)
+{
+  GtkWidget *dialog;
+  gboolean r = 0;
+
+  dialog = gtk_message_dialog_new (NULL,
+				   (GtkDialogFlags)
+				   (GTK_DIALOG_MODAL |
+				    GTK_DIALOG_DESTROY_WITH_PARENT),
+				   GTK_MESSAGE_QUESTION,
+				   GTK_BUTTONS_YES_NO,
+				   primary);
+
+  gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+					    secondary);
+  gtk_widget_show_all (dialog);
+  r = (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_YES);
+  gtk_widget_destroy (dialog);
+  return r;
+}
