@@ -93,8 +93,7 @@ freeit (gpointer data, gpointer user_data);
 void
 warningdialog(gchar *msg);
 
-GtkWidget*
-progressdialog(DenemoGUI *si);
+
 
 void 
 headerfields(GtkWidget *dialog, GtkListStore *list_store, 
@@ -111,5 +110,8 @@ void kill_process (GPid pid);
 
 gchar * music_font(gchar *str);
 
-
+void  set_title_bar(DenemoGUI *gui);
+void score_status(DenemoGUI *gui, gboolean haschanged);
+gboolean
+confirm (gchar *primary, gchar *secondary);
 #endif /* UTILS_H */
